@@ -1,3 +1,5 @@
+// -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
+// vi: set et ts=4 sw=2 sts=2:
 #ifndef DUNE_FACEUTILITY_IMP_HH
 #define DUNE_FACEUTILITY_IMP_HH
 
@@ -5,8 +7,9 @@ namespace Dune
 {
 
 
-  template< ALU3dGridElementType type, class Comm > 
-  inline ALU3dGridFaceInfo< type, Comm >::ALU3dGridFaceInfo() :
+  template< ALU3dGridElementType type, class Comm >
+  inline ALU3dGridFaceInfo< type, Comm >::
+  ALU3dGridFaceInfo( const bool conformingRefinement, const bool ghostCellsEnabled ) :
     face_(0),
     innerElement_(0),
     outerElement_(0),
@@ -17,17 +20,18 @@ namespace Dune
     segmentIndex_( -1 ),
     bndId_( -1 ),
     bndType_( noBoundary ),
-    conformanceState_(UNDEFINED)
-  {
-  }
-  
+    conformanceState_(UNDEFINED),
+    conformingRefinement_( conformingRefinement ),
+    ghostCellsEnabled_( ghostCellsEnabled )
+  {}
+
   // points face from inner element away?
-  template< ALU3dGridElementType type, class Comm > 
-  inline void 
+  template< ALU3dGridElementType type, class Comm >
+  inline void
   ALU3dGridFaceInfo< type, Comm >::
   updateFaceInfo(const GEOFaceType& face,
                  int innerLevel,
-                 int innerTwist) 
+                 int innerTwist)
   {
     face_ = &face;
 
@@ -37,31 +41,31 @@ namespace Dune
     outerFaceNumber_ = -1;
     bndType_ = noBoundary;
     segmentIndex_ = -1;
-    bndId_ = 0; // inner face 
+    bndId_ = 0; // inner face
 
     // points face from inner element away?
-    if (innerTwist < 0) 
+    if (innerTwist < 0)
     {
-      innerElement_ = face.nb.rear().first;
+      innerElement_    = face.nb.rear().first;
       innerFaceNumber_ = face.nb.rear().second;
-      outerElement_ = face.nb.front().first;
+      outerElement_    = face.nb.front().first;
       outerFaceNumber_ = face.nb.front().second;
-    } 
-    else 
+    }
+    else
     {
-      innerElement_ = face.nb.front().first;
+      innerElement_    = face.nb.front().first;
       innerFaceNumber_ = face.nb.front().second;
-      outerElement_ = face.nb.rear().first;
+      outerElement_    = face.nb.rear().first;
       outerFaceNumber_ = face.nb.rear().second;
     } // end if
 
-    // if not true we are accessing a fake bnd 
+    // if not true we are accessing a fake bnd
     assert( innerElement_->isRealObject() );
-    // if not true we are accessing a fake bnd 
+    // if not true we are accessing a fake bnd
     assert( outerElement_->isRealObject() );
-    
-    // we only have to do this in parallel runs 
-    if( parallel() && innerElement_->isboundary() ) 
+
+    // we only have to do this in parallel runs
+    if( parallel() && innerElement_->isboundary() )
     {
       bndType_ = innerGhostBoundary;
       assert( ! dynamic_cast< const GEOPeriodicType* > ( innerElement_ ) );
@@ -69,10 +73,10 @@ namespace Dune
 
     if( parallel() && innerBoundary() )
     {
-      // check for ghosts 
-      // this check is only need in the parallel case 
+      // check for ghosts
+      // this check is only need in the parallel case
       const BNDFaceType * bnd = static_cast<const BNDFaceType *> (innerElement_);
-      
+
       if(bnd->bndtype() == ALU3DSPACE ProcessorBoundary_t)
       {
         // if nonconformity occurs then go up one level
@@ -83,28 +87,28 @@ namespace Dune
           innerElement_ = static_cast<const HasFaceType*> (bnd);
         }
 
-        // get ghost and internal number  
+        // get ghost and internal number
         GhostPairType p  = bnd->getGhost();
 
-        // get face number 
+        // get face number
         innerFaceNumber_ = p.second;
 
-        // this doesn't count as outer boundary 
+        // this doesn't count as outer boundary
         const GEOElementType* ghost = static_cast<const GEOElementType*> (p.first);
         assert(ghost);
 
         innerTwist_ = ghost->twist(innerFaceNumber_);
       }
-      else 
+      else
       {
         innerTwist_ = innerFace().twist(innerALUFaceIndex());
       }
     }
-    else 
+    else
     {
-      // set inner twist 
+      // set inner twist
       assert(innerTwist == innerEntity().twist(innerFaceNumber_));
-      innerTwist_ = innerTwist; 
+      innerTwist_ = innerTwist;
     }
 
     if( outerElement_->isboundary() )
@@ -113,18 +117,18 @@ namespace Dune
       // set to default boundary (with domain boundary)
       bndType_ = domainBoundary ;
 
-      // check for ghosts 
-      // this check is only need in the parallel case 
-      // if this cast fails we have a periodic element 
-//#ifdef ALUGRID_PERIODIC_BOUNDARY_PARALLEL
-///      const bool periodicBnd = outerElement_->isperiodic();
-//      const BNDFaceType * bnd = 0;
-//      const BNDFaceType * bnd = static_cast<const BNDFaceType *> (outerElement_);
-//#else 
+      // check for ghosts
+      // this check is only need in the parallel case
+      // if this cast fails we have a periodic element
+      //#ifdef ALUGRID_PERIODIC_BOUNDARY_PARALLEL
+      ///      const bool periodicBnd = outerElement_->isperiodic();
+      //      const BNDFaceType * bnd = 0;
+      //      const BNDFaceType * bnd = static_cast<const BNDFaceType *> (outerElement_);
+      //#else
       const BNDFaceType * bnd = dynamic_cast<const BNDFaceType *> (outerElement_);
       const bool periodicBnd = ( bnd == 0 ) ;
-//#endif
-      if( periodicBnd ) // the periodic case 
+      //#endif
+      if( periodicBnd ) // the periodic case
       {
         bndType_ = periodicBoundary ;
         assert( dynamic_cast< const GEOPeriodicType* > ( outerElement_ ) );
@@ -133,13 +137,13 @@ namespace Dune
 #ifdef ALUGRID_PERIODIC_BOUNDARY
         // previously, the segmentIndex( 1 - outerFaceNumber_ ) was used, why?
         segmentIndex_ = periodicClosure->segmentIndex( outerFaceNumber_ );
-#else 
+#else
         // set to zero (grid test will fail)
         segmentIndex_ = 0 ;
 #endif
 #ifdef ALUGRID_PERIODIC_BOUNDARY_PARALLEL
         bndId_  = periodicClosure->bndtype( outerFaceNumber_ );
-#endif  
+#endif
 
         const GEOFaceType* face = ImplTraits::getFace( *periodicClosure, 1 - outerFaceNumber_ );
         assert( (face->nb.front().first == periodicClosure) || (face->nb.rear().first == periodicClosure) );
@@ -149,7 +153,7 @@ namespace Dune
           outerElement_    = face->nb.front().first ;
           outerFaceNumber_ = face->nb.front().second ;
         }
-        else 
+        else
         {
           assert( dynamic_cast< const GEOPeriodicType * >( face->nb.front().first ) );
           outerElement_    = face->nb.rear().first ;
@@ -166,13 +170,13 @@ namespace Dune
           outerTwist_ = outerEntity().twist( outerFaceNumber_ );
       }
 
-      if ( bnd ) // the boundary case 
+      if ( bnd ) // the boundary case
       {
         assert( bnd );
 
-        // if this cast is valid we have either 
+        // if this cast is valid we have either
         // a boundary or a ghost element
-        // the ghost element case 
+        // the ghost element case
         if( parallel() && bnd->bndtype() == ALU3DSPACE ProcessorBoundary_t)
         {
           // if nonconformity occurs then go up one level
@@ -183,82 +187,87 @@ namespace Dune
             outerElement_ = static_cast<const HasFaceType*> (bnd);
           }
 
-          // get ghost and internal number  
-          GhostPairType p  = bnd->getGhost();
-          outerFaceNumber_ = p.second;
-
-          // set boundary type to ghost boundary 
+          // set boundary type to ghost boundary
           bndType_ = outerGhostBoundary ;
 
-          const GEOElementType* ghost = static_cast<const GEOElementType*> (p.first);
-          assert(ghost);
+          // access ghost only when ghost cells are enabled
+          if( ghostCellsEnabled_ )
+          {
+            // get ghost and internal number
+            GhostPairType p  = bnd->getGhost();
+            outerFaceNumber_ = p.second;
 
-          outerTwist_ = ghost->twist(outerFaceNumber_);
+            const GEOElementType* ghost = static_cast<const GEOElementType*> (p.first);
+            assert( ghost );
+            outerTwist_ = ghost->twist(outerFaceNumber_);
+          }
         }
-        else // the normal boundary case 
+        else // the normal boundary case
         {
-          // get outer twist 
+          // get outer twist
           outerTwist_ = boundaryFace().twist(outerALUFaceIndex());
-          // store segment index 
+          // store segment index
           segmentIndex_ = boundaryFace().segmentIndex();
           bndId_ = boundaryFace().bndtype();
         }
       }
     }
-    else 
+    else
     {
-      // get outer twist 
+      // get outer twist
       outerTwist_ = outerEntity().twist(outerALUFaceIndex());
     }
 
-    // make sure we got boundary id correctly 
+    // make sure we got boundary id correctly
     assert( bndType_ == periodicBoundary || bndType_ == domainBoundary ? bndId_ > 0 : bndId_ == 0 );
 
-    // set conformance information 
+    // set conformance information
     conformanceState_ = getConformanceState(innerLevel);
   }
 
   // points face from inner element away?
-  template< ALU3dGridElementType type, class Comm > 
+  template< ALU3dGridElementType type, class Comm >
   inline ALU3dGridFaceInfo< type, Comm >::
-  ALU3dGridFaceInfo(const GEOFaceType& face, 
-                    int innerTwist) 
+  ALU3dGridFaceInfo(const GEOFaceType& face,
+                    int innerTwist)
   {
     updateFaceInfo(face,innerTwist);
   }
 
-  template< ALU3dGridElementType type, class Comm > 
+  template< ALU3dGridElementType type, class Comm >
   inline ALU3dGridFaceInfo< type, Comm >::~ALU3dGridFaceInfo() {}
 
-  template< ALU3dGridElementType type, class Comm > 
+  template< ALU3dGridElementType type, class Comm >
   ALU3dGridFaceInfo< type, Comm >::
   ALU3dGridFaceInfo ( const ALU3dGridFaceInfo &orig )
-  : face_(orig.face_),
-    innerElement_(orig.innerElement_),
-    outerElement_(orig.outerElement_),
-    innerFaceNumber_(orig.innerFaceNumber_),
-    outerFaceNumber_(orig.outerFaceNumber_),
-    innerTwist_(orig.innerTwist_),
-    outerTwist_(orig.outerTwist_),
-    segmentIndex_( orig.segmentIndex_ ),
-    bndId_( orig.bndId_ ),
-    bndType_( orig.bndType_ ),
-    conformanceState_(orig.conformanceState_)
+    : face_(orig.face_),
+      innerElement_(orig.innerElement_),
+      outerElement_(orig.outerElement_),
+      innerFaceNumber_(orig.innerFaceNumber_),
+      outerFaceNumber_(orig.outerFaceNumber_),
+      innerTwist_(orig.innerTwist_),
+      outerTwist_(orig.outerTwist_),
+      segmentIndex_( orig.segmentIndex_ ),
+      bndId_( orig.bndId_ ),
+      bndType_( orig.bndType_ ),
+      conformanceState_(orig.conformanceState_),
+      conformingRefinement_( orig.conformingRefinement_ ),
+      ghostCellsEnabled_( orig.ghostCellsEnabled_ )
   {}
 
-  template< ALU3dGridElementType type, class Comm > 
+  template< ALU3dGridElementType type, class Comm >
   inline bool ALU3dGridFaceInfo< type, Comm >::isElementLike() const {
-    return bndType_ < domainBoundary; 
+    return bndType_ < domainBoundary;
   }
 
-  template< ALU3dGridElementType type, class Comm > 
+  template< ALU3dGridElementType type, class Comm >
   inline bool ALU3dGridFaceInfo< type, Comm >::innerBoundary() const {
-    return bndType_ == innerGhostBoundary; 
+    return bndType_ == innerGhostBoundary;
   }
 
-  template< ALU3dGridElementType type, class Comm > 
+  template< ALU3dGridElementType type, class Comm >
   inline bool ALU3dGridFaceInfo< type, Comm >::outerBoundary() const {
-    return bndType_ == domainBoundary; 
+    return bndType_ == domainBoundary;
   }
 
   template< ALU3dGridElementType type, class Comm >
@@ -267,58 +276,58 @@ namespace Dune
   }
 
   template< ALU3dGridElementType type, class Comm >
-  inline bool ALU3dGridFaceInfo< type, Comm >::neighbor() const 
+  inline bool ALU3dGridFaceInfo< type, Comm >::neighbor() const
   {
-    return isElementLike() || ghostBoundary();
+    return isElementLike() || ( ghostBoundary() && ghostCellsEnabled_ );
   }
 
   template< ALU3dGridElementType type, class Comm >
-  inline bool ALU3dGridFaceInfo< type, Comm >::ghostBoundary () const 
+  inline bool ALU3dGridFaceInfo< type, Comm >::ghostBoundary () const
   {
-    // when communicator is No_Comm there is no ghost boundary 
+    // when communicator is No_Comm there is no ghost boundary
     return parallel() ? ( bndType_ == outerGhostBoundary ) : false ;
   }
 
-  template< ALU3dGridElementType type, class Comm > 
-  inline const typename ALU3dGridFaceInfo< type, Comm >::GEOFaceType& 
-  ALU3dGridFaceInfo< type, Comm >::face() const 
+  template< ALU3dGridElementType type, class Comm >
+  inline const typename ALU3dGridFaceInfo< type, Comm >::GEOFaceType&
+  ALU3dGridFaceInfo< type, Comm >::face() const
   {
     return *face_;
   }
 
-  template< ALU3dGridElementType type, class Comm > 
-  inline const typename ALU3dGridFaceInfo< type, Comm >::GEOElementType& 
-  ALU3dGridFaceInfo< type, Comm >::innerEntity() const 
+  template< ALU3dGridElementType type, class Comm >
+  inline const typename ALU3dGridFaceInfo< type, Comm >::GEOElementType&
+  ALU3dGridFaceInfo< type, Comm >::innerEntity() const
   {
     assert( ! innerElement_->isboundary() );
     return static_cast<const GEOElementType&>(*innerElement_);
   }
 
-  template< ALU3dGridElementType type, class Comm > 
-  inline const typename ALU3dGridFaceInfo< type, Comm >::GEOElementType& 
-  ALU3dGridFaceInfo< type, Comm >::outerEntity() const 
+  template< ALU3dGridElementType type, class Comm >
+  inline const typename ALU3dGridFaceInfo< type, Comm >::GEOElementType&
+  ALU3dGridFaceInfo< type, Comm >::outerEntity() const
   {
     assert( isElementLike() );
     return static_cast<const GEOElementType&>(*outerElement_);
   }
 
   template< ALU3dGridElementType type, class Comm >
-  inline const typename ALU3dGridFaceInfo< type, Comm >::BNDFaceType& 
-  ALU3dGridFaceInfo< type, Comm >::innerFace() const 
+  inline const typename ALU3dGridFaceInfo< type, Comm >::BNDFaceType&
+  ALU3dGridFaceInfo< type, Comm >::innerFace() const
   {
-    assert( innerElement_->isboundary() ); 
+    assert( innerElement_->isboundary() );
     return static_cast<const BNDFaceType&>(*innerElement_);
   }
 
   template< ALU3dGridElementType type, class Comm >
-  inline const typename ALU3dGridFaceInfo< type, Comm >::BNDFaceType& 
+  inline const typename ALU3dGridFaceInfo< type, Comm >::BNDFaceType&
   ALU3dGridFaceInfo< type, Comm >::boundaryFace() const {
     assert( ! isElementLike() );
     return static_cast<const BNDFaceType&>(*outerElement_);
   }
 
   template< ALU3dGridElementType type, class Comm >
-  inline int ALU3dGridFaceInfo< type, Comm >::outsideLevel() const 
+  inline int ALU3dGridFaceInfo< type, Comm >::outsideLevel() const
   {
     assert( outerElement_ );
     assert( !isElementLike() || outerEntity().level() == outerElement_->nbLevel() );
@@ -327,29 +336,29 @@ namespace Dune
   }
 
   template< ALU3dGridElementType type, class Comm >
-  inline int ALU3dGridFaceInfo< type, Comm >::segmentIndex() const 
+  inline int ALU3dGridFaceInfo< type, Comm >::segmentIndex() const
   {
     assert( segmentIndex_ >= 0 );
     return segmentIndex_;
   }
 
   template< ALU3dGridElementType type, class Comm >
-  inline int ALU3dGridFaceInfo< type, Comm >::boundaryId() const 
+  inline int ALU3dGridFaceInfo< type, Comm >::boundaryId() const
   {
     return bndId_;
   }
 
   template< ALU3dGridElementType type, class Comm >
-  inline int ALU3dGridFaceInfo< type, Comm >::innerTwist() const 
+  inline int ALU3dGridFaceInfo< type, Comm >::innerTwist() const
   {
-    // don't check ghost boundaries here 
-    assert( ( ! innerBoundary() ) ? 
-        innerEntity().twist(innerALUFaceIndex()) == innerTwist_ : true );
-    return innerTwist_; 
+    // don't check ghost boundaries here
+    assert( ( ! innerBoundary() ) ?
+            innerEntity().twist(innerALUFaceIndex()) == innerTwist_ : true );
+    return innerTwist_;
   }
 
   template< ALU3dGridElementType type, class Comm >
-  inline int ALU3dGridFaceInfo< type, Comm >::duneTwist(const int faceIdx, const int aluTwist) const 
+  inline int ALU3dGridFaceInfo< type, Comm >::duneTwist(const int faceIdx, const int aluTwist) const
   {
     typedef ElementTopologyMapping<type> ElementTopo;
     typedef FaceTopologyMapping<type> FaceTopo;
@@ -357,7 +366,7 @@ namespace Dune
     const int mappedZero =
       FaceTopo::twist(ElementTopo::dune2aluFaceVertex( faceIdx, 0), aluTwist);
 
-    const int twist = 
+    const int twist =
       (ElementTopo::faceOrientation( faceIdx ) * sign(aluTwist) < 0 ?
        mappedZero : -mappedZero-1);
 
@@ -366,15 +375,15 @@ namespace Dune
   }
 
   template< ALU3dGridElementType type, class Comm >
-  inline int ALU3dGridFaceInfo< type, Comm >::outerTwist() const 
+  inline int ALU3dGridFaceInfo< type, Comm >::outerTwist() const
   {
-    // don't check ghost boundaries here 
+    // don't check ghost boundaries here
     //assert( (outerBoundary_) ?
     //          (outerTwist_ == boundaryFace().twist(0)) :
     //          (! ghostBoundary_) ?
     //          (outerTwist_ == outerEntity().twist(outerALUFaceIndex())) : true
     //      );
-    return outerTwist_; 
+    return outerTwist_;
   }
 
   template< ALU3dGridElementType type, class Comm >
@@ -387,35 +396,39 @@ namespace Dune
     return outerFaceNumber_;
   }
 
-  template< ALU3dGridElementType type, class Comm > 
-  typename ALU3dGridFaceInfo< type, Comm >::ConformanceState 
-  inline ALU3dGridFaceInfo< type, Comm >::conformanceState() const 
+  template< ALU3dGridElementType type, class Comm >
+  typename ALU3dGridFaceInfo< type, Comm >::ConformanceState
+  inline ALU3dGridFaceInfo< type, Comm >::conformanceState() const
   {
     assert( conformanceState_ != UNDEFINED );
     return conformanceState_;
   }
 
-  // calculate conformance state 
-  template< ALU3dGridElementType type, class Comm > 
-  typename ALU3dGridFaceInfo< type, Comm >::ConformanceState 
-  inline ALU3dGridFaceInfo< type, Comm >::getConformanceState(const int innerLevel) const 
+  // calculate conformance state
+  template< ALU3dGridElementType type, class Comm >
+  typename ALU3dGridFaceInfo< type, Comm >::ConformanceState
+  inline ALU3dGridFaceInfo< type, Comm >::getConformanceState(const int innerLevel) const
   {
     ConformanceState result = CONFORMING;
 
-    // A boundary is always unrefined
-    int levelDifference = 0 ;
-    if ( isElementLike() )
-      levelDifference = innerLevel - outerEntity().level();
-    else
-      levelDifference = innerLevel - boundaryFace().level();
-    
-    if (levelDifference < 0) {
-      result = REFINED_OUTER;
-    } 
-    else if (levelDifference > 0) {
-      result = REFINED_INNER;
+    // in case of non-conforming refinement check level difference
+    if( ! conformingRefinement_ )
+    {
+      // A boundary is always unrefined
+      int levelDifference = 0 ;
+      if ( isElementLike() )
+        levelDifference = innerLevel - outerEntity().level();
+      else
+        levelDifference = innerLevel - boundaryFace().level();
+
+      if (levelDifference < 0) {
+        result = REFINED_OUTER;
+      }
+      else if (levelDifference > 0) {
+        result = REFINED_INNER;
+      }
     }
-    
+
     return result;
   }
 
@@ -430,10 +443,10 @@ namespace Dune
   {}
 
   template< ALU3dGridElementType type, class Comm >
-  inline void 
+  inline void
   ALU3dGridGeometricFaceInfoBase< type, Comm >::
-  resetFaceGeom() 
-  { 
+  resetFaceGeom()
+  {
     generatedGlobal_ = false;
     generatedLocal_  = false;
   }
@@ -441,15 +454,15 @@ namespace Dune
   template< ALU3dGridElementType type, class Comm >
   inline ALU3dGridGeometricFaceInfoBase< type, Comm >::
   ALU3dGridGeometricFaceInfoBase ( const ALU3dGridGeometricFaceInfoBase &orig )
-  : connector_(orig.connector_),
-    coordsSelfLocal_(orig.coordsSelfLocal_),
-    coordsNeighborLocal_(orig.coordsNeighborLocal_),
-    generatedGlobal_(orig.generatedGlobal_),
-    generatedLocal_(orig.generatedLocal_)
+    : connector_(orig.connector_),
+      coordsSelfLocal_(orig.coordsSelfLocal_),
+      coordsNeighborLocal_(orig.coordsNeighborLocal_),
+      generatedGlobal_(orig.generatedGlobal_),
+      generatedLocal_(orig.generatedLocal_)
   {}
 
   template< ALU3dGridElementType type, class Comm >
-  inline const typename ALU3dGridGeometricFaceInfoBase< type, Comm >::CoordinateType& 
+  inline const typename ALU3dGridGeometricFaceInfoBase< type, Comm >::CoordinateType&
   ALU3dGridGeometricFaceInfoBase< type, Comm >::intersectionSelfLocal() const {
     generateLocalGeometries();
     assert(generatedLocal_);
@@ -457,7 +470,7 @@ namespace Dune
   }
 
   template< ALU3dGridElementType type, class Comm >
-  inline const typename ALU3dGridGeometricFaceInfoBase< type, Comm >::CoordinateType& 
+  inline const typename ALU3dGridGeometricFaceInfoBase< type, Comm >::CoordinateType&
   ALU3dGridGeometricFaceInfoBase< type, Comm >::intersectionNeighborLocal() const {
     assert(!connector_.outerBoundary());
     generateLocalGeometries();
@@ -469,37 +482,37 @@ namespace Dune
   //sepcialisation for tetra and hexa
   template< class Comm >
   inline ALU3dGridGeometricFaceInfoTetra< Comm >::
-  ALU3dGridGeometricFaceInfoTetra(const ConnectorType& connector) 
-  : Base( connector ), normalUp2Date_( false )
+  ALU3dGridGeometricFaceInfoTetra(const ConnectorType& connector)
+    : Base( connector ), normalUp2Date_( false )
   {}
 
   template< class Comm >
   inline void ALU3dGridGeometricFaceInfoTetra< Comm >::
-  resetFaceGeom() 
-  { 
+  resetFaceGeom()
+  {
     Base::resetFaceGeom();
     normalUp2Date_ = false;
   }
 
   template< class Comm >
   inline ALU3dGridGeometricFaceInfoTetra< Comm >::
-  ALU3dGridGeometricFaceInfoTetra(const ALU3dGridGeometricFaceInfoTetra& orig) 
-  : Base( orig ), normalUp2Date_( orig.normalUp2Date_ )
+  ALU3dGridGeometricFaceInfoTetra(const ALU3dGridGeometricFaceInfoTetra& orig)
+    : Base( orig ), normalUp2Date_( orig.normalUp2Date_ )
   {}
 
   template< class Comm >
-  template <class GeometryImp> 
+  template <class GeometryImp>
   inline void
   ALU3dGridGeometricFaceInfoTetra< Comm >::
-  buildGlobalGeom(GeometryImp& geo) const 
+  buildGlobalGeom(GeometryImp& geo) const
   {
-    if (! this->generatedGlobal_) 
+    if (! this->generatedGlobal_)
     {
       // calculate the normal
       const GEOFaceType & face = this->connector_.face();
-    
+
       geo.buildGeom( face.myvertex(FaceTopo::dune2aluVertex(0))->Point() ,
-                     face.myvertex(FaceTopo::dune2aluVertex(1))->Point() ,  
+                     face.myvertex(FaceTopo::dune2aluVertex(1))->Point() ,
                      face.myvertex(FaceTopo::dune2aluVertex(2))->Point() );
 
       this->generatedGlobal_ = true ;
@@ -509,9 +522,9 @@ namespace Dune
   template< class Comm >
   inline FieldVector<alu3d_ctype, 3> &
   ALU3dGridGeometricFaceInfoTetra< Comm >::
-  outerNormal(const FieldVector<alu3d_ctype, 2>& local) const 
+  outerNormal(const FieldVector<alu3d_ctype, 2>& local) const
   {
-    // if geomInfo was not reseted then normal is still correct 
+    // if geomInfo was not reseted then normal is still correct
     if(!normalUp2Date_)
     {
       // calculate the normal
@@ -521,10 +534,10 @@ namespace Dune
       const alu3d_ctype (&_p2)[3] = face.myvertex(2)->Point();
 
       // change sign if face normal points into inner element
-      // factor is 1.0 to get integration outer normal and not volume outer normal 
-      const double factor = (this->connector_.innerTwist() < 0) ? 1.0 : -1.0; 
+      // factor is 1.0 to get integration outer normal and not volume outer normal
+      const double factor = (this->connector_.innerTwist() < 0) ? 1.0 : -1.0;
 
-      // see mapp_tetra_3d.h for this piece of code 
+      // see mapp_tetra_3d.h for this piece of code
       outerNormal_[0] = factor * ((_p1[1]-_p0[1]) *(_p2[2]-_p1[2]) - (_p2[1]-_p1[1]) *(_p1[2]-_p0[2]));
       outerNormal_[1] = factor * ((_p1[2]-_p0[2]) *(_p2[0]-_p1[0]) - (_p2[2]-_p1[2]) *(_p1[0]-_p0[0]));
       outerNormal_[2] = factor * ((_p1[0]-_p0[0]) *(_p2[1]-_p1[1]) - (_p2[0]-_p1[0]) *(_p1[1]-_p0[1]));
@@ -535,42 +548,42 @@ namespace Dune
     return outerNormal_;
   }
 
-  //-sepcialisation for and hexa 
+  //-sepcialisation for and hexa
   template< class Comm >
   inline ALU3dGridGeometricFaceInfoHexa< Comm >::
-  ALU3dGridGeometricFaceInfoHexa(const ConnectorType& connector) 
-  : Base( connector )
-    , mappingGlobal_()
-    , mappingGlobalUp2Date_(false) 
+  ALU3dGridGeometricFaceInfoHexa(const ConnectorType& connector)
+    : Base( connector )
+      , mappingGlobal_()
+      , mappingGlobalUp2Date_(false)
   {}
 
   template< class Comm >
   inline void ALU3dGridGeometricFaceInfoHexa< Comm >::
-  resetFaceGeom() 
-  { 
+  resetFaceGeom()
+  {
     Base::resetFaceGeom();
     mappingGlobalUp2Date_ = false;
   }
 
   template< class Comm >
   inline ALU3dGridGeometricFaceInfoHexa< Comm >::
-  ALU3dGridGeometricFaceInfoHexa(const ALU3dGridGeometricFaceInfoHexa& orig) 
-  : Base( orig )
-    , mappingGlobal_(orig.mappingGlobal_)
-    , mappingGlobalUp2Date_(orig.mappingGlobalUp2Date_) 
+  ALU3dGridGeometricFaceInfoHexa(const ALU3dGridGeometricFaceInfoHexa& orig)
+    : Base( orig )
+      , mappingGlobal_(orig.mappingGlobal_)
+      , mappingGlobalUp2Date_(orig.mappingGlobalUp2Date_)
   {}
 
   template< class Comm >
-  template <class GeometryImp> 
+  template <class GeometryImp>
   inline void
   ALU3dGridGeometricFaceInfoHexa< Comm >::
-  buildGlobalGeom(GeometryImp& geo) const 
+  buildGlobalGeom(GeometryImp& geo) const
   {
-    if (! this->generatedGlobal_) 
+    if (! this->generatedGlobal_)
     {
       // calculate the normal
       const GEOFaceType & face = this->connector_.face();
-      
+
       geo.buildGeom( face.myvertex(FaceTopo::dune2aluVertex(0))->Point() ,
                      face.myvertex(FaceTopo::dune2aluVertex(1))->Point() ,
                      face.myvertex(FaceTopo::dune2aluVertex(2))->Point() ,
@@ -582,9 +595,9 @@ namespace Dune
   template< class Comm >
   inline FieldVector<alu3d_ctype, 3> &
   ALU3dGridGeometricFaceInfoHexa< Comm >::
-  outerNormal(const FieldVector<alu3d_ctype, 2>& local) const 
+  outerNormal(const FieldVector<alu3d_ctype, 2>& local) const
   {
-    // if mapping calculated and affine, nothing more to do  
+    // if mapping calculated and affine, nothing more to do
     if ( mappingGlobal_.affine () && mappingGlobalUp2Date_ )
       return outerNormal_ ;
 
@@ -592,7 +605,7 @@ namespace Dune
     if(! mappingGlobalUp2Date_ )
     {
       const GEOFaceType & face = connector_.face();
-      // update mapping to actual face 
+      // update mapping to actual face
       mappingGlobal_.buildMapping(
         face.myvertex( FaceTopo::dune2aluVertex(0) )->Point(),
         face.myvertex( FaceTopo::dune2aluVertex(1) )->Point(),
@@ -603,11 +616,11 @@ namespace Dune
     }
 
     // calculate the normal
-    // has to be calculated every time normal called, because 
-    // depends on local 
-    if (connector_.innerTwist() < 0) 
+    // has to be calculated every time normal called, because
+    // depends on local
+    if (connector_.innerTwist() < 0)
       mappingGlobal_.negativeNormal(local,outerNormal_);
-    else 
+    else
       mappingGlobal_.normal(local,outerNormal_);
 
     // end if
@@ -616,13 +629,13 @@ namespace Dune
 
   template< ALU3dGridElementType type, class Comm >
   inline void ALU3dGridGeometricFaceInfoBase< type, Comm >::
-  generateLocalGeometries() const 
+  generateLocalGeometries() const
   {
     if (!generatedLocal_) {
       // Get the coordinates of the face in the reference element of the
-      // adjoining inner and outer elements and initialise the respective 
+      // adjoining inner and outer elements and initialise the respective
       // geometries
-      switch (connector_.conformanceState()) 
+      switch (connector_.conformanceState())
       {
       case (ConnectorType::CONFORMING) :
         referenceElementCoordinatesRefined(INNER, coordsSelfLocal_);
@@ -652,18 +665,18 @@ namespace Dune
 
   template< ALU3dGridElementType type, class Comm >
   inline int ALU3dGridGeometricFaceInfoBase< type, Comm >::
-  globalVertexIndex(const int duneFaceIndex, 
+  globalVertexIndex(const int duneFaceIndex,
                     const int aluFaceTwist,
-                    const int duneFaceVertexIndex) const 
+                    const int duneFaceVertexIndex) const
   {
-    const int localALUIndex = 
-      FaceTopo::dune2aluVertex(duneFaceVertexIndex, 
+    const int localALUIndex =
+      FaceTopo::dune2aluVertex(duneFaceVertexIndex,
                                aluFaceTwist);
 
     // get local ALU vertex number on the element's face
     const int localDuneIndex = ElementTopo::
-        alu2duneFaceVertex(ElementTopo::dune2aluFace(duneFaceIndex),
-                           localALUIndex);
+                               alu2duneFaceVertex(ElementTopo::dune2aluFace(duneFaceIndex),
+                                                  localALUIndex);
 
     return getReferenceElement().subEntity(duneFaceIndex, 1, localDuneIndex, 3);
   }
@@ -671,24 +684,24 @@ namespace Dune
 
   template< ALU3dGridElementType type, class Comm >
   inline void ALU3dGridGeometricFaceInfoBase< type, Comm >::
-  referenceElementCoordinatesRefined(SideIdentifier side, 
-                                     CoordinateType& result) const 
+  referenceElementCoordinatesRefined(SideIdentifier side,
+                                     CoordinateType& result) const
   {
     // this is a dune face index
-    const int faceIndex = 
-      (side == INNER ? 
+    const int faceIndex =
+      (side == INNER ?
        ElementTopo::alu2duneFace(connector_.innerALUFaceIndex()) :
        ElementTopo::alu2duneFace(connector_.outerALUFaceIndex()));
-    const int faceTwist = 
+    const int faceTwist =
       (side == INNER ?
        connector_.innerTwist() :
        connector_.outerTwist());
 
     const ReferenceElementType& refElem = getReferenceElement();
 
-    for (int i = 0; i < numVerticesPerFace; ++i) 
+    for (int i = 0; i < numVerticesPerFace; ++i)
     {
-      int duneVertexIndex = globalVertexIndex(faceIndex, faceTwist, i); 
+      int duneVertexIndex = globalVertexIndex(faceIndex, faceTwist, i);
       result[i] = refElem.position(duneVertexIndex, 3);
     }
   }
