@@ -55,7 +55,7 @@ void checkElementDataMapper(const Mapper& mapper, const GridView& gridView)
 
   for (; eIt!=eEndIt; ++eIt)
   {
-    size_t index = mapper.map(*eIt);
+    size_t index = mapper.index(*eIt);
     min = std::min(min, index);
     max = std::max(max, index);
     std::pair<std::set<int>::iterator, bool> status = indices.insert(index);
@@ -90,10 +90,10 @@ void checkVertexDataMapper(const Mapper& mapper, const GridView& gridView)
 
   for (; eIt!=eEndIt; ++eIt)
   {
-    size_t numVertices = eIt->template count<dim>();
+    size_t numVertices = eIt->subEntities(dim);
     for (size_t curVertex = 0; curVertex < numVertices; ++curVertex)
     {
-      size_t index = mapper.map(*eIt, curVertex, dim);
+      size_t index = mapper.subIndex(*eIt, curVertex, dim);
       min = std::min(min, index);
       max = std::max(max, index);
       indices.insert(index);
@@ -133,7 +133,7 @@ void checkMixedDataMapper(const Mapper& mapper, const GridView& gridView)
   for (; eIt!=eEndIt; ++eIt)
   {
     // handle elements
-    size_t index = mapper.map(*eIt);
+    size_t index = mapper.index(*eIt);
     min = std::min(min, index);
     max = std::max(max, index);
     std::pair<std::set<int>::iterator, bool> status = indices.insert(index);
@@ -142,10 +142,10 @@ void checkMixedDataMapper(const Mapper& mapper, const GridView& gridView)
       DUNE_THROW(GridError, "Mapper mixed index is not unique for elements!");
 
     // handle edges
-    size_t numEdges = eIt->template count<dim - 1>();
+    size_t numEdges = eIt->subEntities(dim-1);
     for (size_t curEdge = 0; curEdge < numEdges; ++curEdge)
     {
-      index = mapper.map(*eIt, curEdge, dim - 1);
+      index = mapper.subIndex(*eIt, curEdge, dim - 1);
       min = std::min(min, index);
       max = std::max(max, index);
       indices.insert(index);
@@ -179,12 +179,12 @@ void checkGrid(const Grid& grid)
   {   // check constructor without layout class
     LeafMultipleCodimMultipleGeomTypeMapper<Grid, MCMGElementLayout>
     leafMCMGMapper(grid);
-    checkElementDataMapper(leafMCMGMapper, grid.leafView());
+    checkElementDataMapper(leafMCMGMapper, grid.leafGridView());
   }
   {   // check constructor with layout class
     LeafMultipleCodimMultipleGeomTypeMapper<Grid, MCMGElementLayout>
     leafMCMGMapper(grid, MCMGElementLayout<dim>());
-    checkElementDataMapper(leafMCMGMapper, grid.leafView());
+    checkElementDataMapper(leafMCMGMapper, grid.leafGridView());
   }
 
   // check levelMCMGMapper
@@ -207,12 +207,12 @@ void checkGrid(const Grid& grid)
   {   // check constructor without layout class
     LeafMultipleCodimMultipleGeomTypeMapper<Grid, MCMGVertexLayout>
     leafMCMGMapper(grid);
-    checkVertexDataMapper(leafMCMGMapper, grid.leafView());
+    checkVertexDataMapper(leafMCMGMapper, grid.leafGridView());
   }
   {   // check constructor with layout class
     LeafMultipleCodimMultipleGeomTypeMapper<Grid, MCMGVertexLayout>
     leafMCMGMapper(grid, MCMGVertexLayout<dim>());
-    checkVertexDataMapper(leafMCMGMapper, grid.leafView());
+    checkVertexDataMapper(leafMCMGMapper, grid.leafGridView());
   }
 
   // check levelMCMGMapper
@@ -235,12 +235,12 @@ void checkGrid(const Grid& grid)
   {   // check constructor without layout class
     LeafMultipleCodimMultipleGeomTypeMapper<Grid, MCMGElementEdgeLayout>
     leafMCMGMapper(grid);
-    checkMixedDataMapper(leafMCMGMapper, grid.leafView());
+    checkMixedDataMapper(leafMCMGMapper, grid.leafGridView());
   }
   {   // check constructor with layout class
     LeafMultipleCodimMultipleGeomTypeMapper<Grid, MCMGElementEdgeLayout>
     leafMCMGMapper(grid, MCMGElementEdgeLayout<dim>());
-    checkMixedDataMapper(leafMCMGMapper, grid.leafView());
+    checkMixedDataMapper(leafMCMGMapper, grid.leafGridView());
   }
 
   // check levelMCMGMapper
@@ -271,7 +271,7 @@ try
   //  Do the test for a 2d UGGrid
   {
     typedef UGGrid<2> Grid;
-    std::auto_ptr<Grid> grid(make2DHybridTestGrid<Grid>());
+    std::unique_ptr<Grid> grid(make2DHybridTestGrid<Grid>());
 
     // create hybrid grid
     grid->mark(1, * grid->leafbegin<0>());
@@ -284,7 +284,7 @@ try
   //  Do the  test for a 3d UGGrid
   {
     typedef UGGrid<3> Grid;
-    std::auto_ptr<Grid> grid(make3DHybridTestGrid<Grid>());
+    std::unique_ptr<Grid> grid(make3DHybridTestGrid<Grid>());
 
     // create hybrid grid
     grid->mark(1, * grid->leafbegin<0>());
