@@ -28,14 +28,16 @@ void checkElementDataMapper(const Mapper& mapper, const GridView& gridView)
   typedef typename GridView::IndexSet IndexSet;
   const IndexSet &is = gridView.indexSet();
 
+  typedef typename Mapper::Index Index;
+
   typedef typename GridView::template Codim<0>::Iterator Iterator;
 
   Iterator eIt    = gridView.template begin<0>();
   Iterator eEndIt = gridView.template end<0>();
 
-  int min = 1;
-  int max = 0;
-  std::set<int> indices;
+  Index min = 1;
+  Index max = 0;
+  std::set<Index> indices;
   int size = mapper.size();
 
   if (size != int(is.size(0)))
@@ -44,18 +46,24 @@ void checkElementDataMapper(const Mapper& mapper, const GridView& gridView)
 
   for (; eIt!=eEndIt; ++eIt) {
 
-    int index;
+    Index index;
     bool contained = mapper.contains(*eIt, index);
 
-    if ((is.geomTypes(0)[0] == eIt->type()) != contained)
+    if ((is.types(0)[0] == eIt->type()) != contained)
       DUNE_THROW(GridError, "Mapper::contains() does not agree with the "
                  "element's geometry type!");
     if (!contained)
       continue;
 
+#if !DISABLE_DEPRECATED_METHOD_CHECK
     if (index != mapper.map(*eIt))
       DUNE_THROW(GridError, "Mapper::contains() and mapper.map() "
-                 "compute different indicex!");
+                 "compute different indices!");
+#endif
+
+    if (index != mapper.index(*eIt))
+      DUNE_THROW(GridError, "Mapper::contains() and mapper.index() "
+                 "compute different indices!");
 
     min = std::min(min, index);
     max = std::max(max, index);
@@ -72,7 +80,7 @@ void checkElementDataMapper(const Mapper& mapper, const GridView& gridView)
     //     assert(oldindex == index);
     // }
 
-    std::pair<std::set<int>::iterator, bool> status = indices.insert(index);
+    std::pair<typename std::set<Index>::iterator, bool> status = indices.insert(index);
 
     if (!status.second)       // not inserted because already existing
       DUNE_THROW(GridError, "Mapper element index is not unique!");
@@ -119,7 +127,7 @@ int main (int argc, char** argv) try
     grid.globalRefine(1);
 
     LeafSingleCodimSingleGeomTypeMapper<GridType, 0> leafMapper(grid);
-    checkElementDataMapper(leafMapper, grid.leafView());
+    checkElementDataMapper(leafMapper, grid.leafGridView());
 
     for (int i=2; i<=grid.maxLevel(); i++) {
       LevelSingleCodimSingleGeomTypeMapper<GridType, 0> levelMapper(grid, i);
