@@ -74,22 +74,27 @@ void Dune::AmiraMeshWriter<GridView>::addGrid(const GridView& gridView,
   // ////////////////////////////////////////////////////////////////////
 
 
+  typedef typename GridView::IndexSet::Types GeomTypes;
+  const GeomTypes& geomTypes = indexSet.types(0);
 
   if (splitAll) {
     Dune::GeometryType coerceTo(Dune::GeometryType::simplex,dim);
     noOfElements = 0;
     int count=0;
 
-    for (size_t i=0; i<indexSet.geomTypes(0).size(); i++) {
+    typename GeomTypes::const_iterator gt = geomTypes.begin();
+    typename GeomTypes::const_iterator gtEnd = geomTypes.end();
 
-      if (indexSet.geomTypes(0)[i].isSimplex())
+    for (; gt != gtEnd; ++gt) {
+
+      if (gt->isSimplex())
         count=1;
       else {
-        Refinement & refinement = Dune::buildRefinement<dim, ct>(indexSet.geomTypes(0)[i],coerceTo);
+        Refinement & refinement = Dune::buildRefinement<dim,ct>(*gt,coerceTo);
         count = refinement.nElements(0);
       }
 
-      noOfElements += count * indexSet.size(indexSet.geomTypes(0)[i]);
+      noOfElements += count * indexSet.size(*gt);
 
     }
 
@@ -165,8 +170,7 @@ void Dune::AmiraMeshWriter<GridView>::addGrid(const GridView& gridView,
     // it is written in TetraGrid format.  If not, it is written in
     // hexagrid format.
     bool containsOnlySimplices =
-      (indexSet.geomTypes(0).size()==1)
-      && (indexSet.geomTypes(0)[0].isSimplex());
+      (geomTypes.size()==1) && (geomTypes.begin()->isSimplex());
 
     int maxVerticesPerElement = (dim==3)
                                 ? ((containsOnlySimplices) ? 4 : 8)
@@ -313,7 +317,7 @@ template<class GridView>
 template<class GridType2>
 void Dune::AmiraMeshWriter<GridView>::addLeafGrid(const GridType2& grid, bool splitAll)
 {
-  addGrid(grid.leafView(), splitAll);
+  addGrid(grid.leafGridView(), splitAll);
 }
 
 
@@ -336,9 +340,9 @@ void Dune::AmiraMeshWriter<GridView>::addCellData(const DataContainer& data,
   // Find out whether the grid contains only tetrahedra.  If yes, then
   // it is written in TetraGrid format.  If not, it is written in
   // hexagrid format (if gridSplitUp=false).
+  const typename GridView::IndexSet::Types& geomTypes = indexSet.types(0);
   bool containsOnlyTetrahedra =
-    (indexSet.geomTypes(0).size()==1)
-    && (indexSet.geomTypes(0)[0].isSimplex());
+      (geomTypes.size()==1) && (geomTypes.begin()->isSimplex());
 
   // Get number of components
   const int ncomp = DataContainer::block_type::dimension;
@@ -364,17 +368,21 @@ void Dune::AmiraMeshWriter<GridView>::addCellData(const DataContainer& data,
       int noOfElements = 0;
       int count;
 
-      for (size_t i=0; i<indexSet.geomTypes(0).size(); i++)
+      typedef typename GridView::IndexSet::Types::const_iterator GeomTypeIterator;
+      GeomTypeIterator gt = geomTypes.begin();
+      GeomTypeIterator gtEnd = geomTypes.end();
+
+      for (; gt != gtEnd; ++gt)
       {
-        if (indexSet.geomTypes(0)[i].isSimplex())
+        if (gt->isSimplex())
           count=1;
         else
         {
-          Refinement & refinement = Dune::buildRefinement<dim, ct>(indexSet.geomTypes(0)[i],coerceTo);
+          Refinement & refinement = Dune::buildRefinement<dim, ct>(*gt,coerceTo);
           count = refinement.nElements(0);
         }
 
-        noOfElements += count * indexSet.size(indexSet.geomTypes(0)[i]);
+        noOfElements += count * indexSet.size(*gt);
       }
 
       amLocation = new AmiraMesh::Location((dim==2) ? "Triangles" : "Tetrahedra", noOfElements);
@@ -454,9 +462,9 @@ void Dune::AmiraMeshWriter<GridView>::addVertexData(const DataContainer& data,
   // Find out whether the grid contains only tetrahedra.  If yes, then
   // it is written in TetraGrid format.  If not, it is written in
   // hexagrid format (if gridSplitUp=false).
+  const typename GridView::IndexSet::Types& geomTypes = indexSet.types(0);
   bool containsOnlyTetrahedra =
-    (indexSet.geomTypes(0).size()==1)
-    && (indexSet.geomTypes(0)[0].isSimplex());
+      (geomTypes.size()==1) && (geomTypes.begin()->isSimplex());
 
   // Get number of components
   const int ncomp = DataContainer::value_type::dimension;
@@ -557,7 +565,7 @@ void Dune::AmiraMeshWriter<GridView>::addUniformData(const GridView& gridView,
                                                      const array<unsigned int, dim>& n,
                                                      const DataContainer& data)
 {
-  dune_static_assert(dim==2 || dim==3, "You can only write 2d and 3d uniform data to AmiraMesh");
+  static_assert(dim==2 || dim==3, "You can only write 2d and 3d uniform data to AmiraMesh");
 
   // ///////////////////////////////////////////
   //   Detect grid bounding box
