@@ -2,7 +2,7 @@
 // vi: set et ts=4 sw=2 sts=2:
 #include "config.h"
 
-#include <dune/grid/sgrid.hh>
+#include <dune/grid/yaspgrid.hh>
 #if HAVE_UG
 #include <dune/grid/uggrid.hh>
 #endif
@@ -22,7 +22,7 @@ template <class GridType>
 void testReadingUnstructuredGrid(const std::string& filename) {
 
   // Read the grid
-  std::auto_ptr<GridType> grid(AmiraMeshReader<GridType>::read(filename));
+  std::unique_ptr<GridType> grid(AmiraMeshReader<GridType>::read(filename));
 
   // Write the grid into a tmp file
   LeafAmiraMeshWriter<GridType> amiramesh(*grid);
@@ -35,45 +35,46 @@ void testReadingUnstructuredGrid(const std::string& filename) {
 
 void testWritingUniformData() {
 
-  int n[3] = { 10, 10, 10 };
-  double h[3] = {3.0, 2.0, 1.0 };
+  std::array<int,2>     n = { {10, 10} };
+  FieldVector<double,2> h = {3.0, 2.0};
 
   // /////////////////////////////////////
   //   Test writing of 2d uniform grid
   // /////////////////////////////////////
-  SGrid<2,2> sgrid2d(n,h);
+  YaspGrid<2> grid2d(h,n);
 
   // create data buffer
-  std::vector<FieldVector<double,1> > vertexdata2d(sgrid2d.size(2));
+  std::vector<FieldVector<double,1> > vertexdata2d(grid2d.size(2));
 
-  SGrid<2,2>::Codim<2>::LeafIterator vIt2d    = sgrid2d.leafbegin<2>();
-  SGrid<2,2>::Codim<2>::LeafIterator vEndIt2d = sgrid2d.leafend<2>();
+  YaspGrid<2>::Codim<2>::LeafIterator vIt2d    = grid2d.leafbegin<2>();
+  YaspGrid<2>::Codim<2>::LeafIterator vEndIt2d = grid2d.leafend<2>();
 
   for (; vIt2d!=vEndIt2d; ++vIt2d)
-    vertexdata2d[sgrid2d.leafIndexSet().index(*vIt2d)] = vIt2d->geometry().corner(0).two_norm();
+    vertexdata2d[grid2d.leafIndexSet().index(*vIt2d)] = vIt2d->geometry().corner(0).two_norm();
 
   array<unsigned int, 2> n2;
   n2[0] = n[0]+1;
   n2[1] = n[1]+1;
 
   // write data
-  AmiraMeshWriter<SGrid<2,2>::LeafGridView> amiramesh2d;
-  amiramesh2d.addUniformData(sgrid2d.leafView(), n2, vertexdata2d);
-  amiramesh2d.write("sgrid2d.am");
+  AmiraMeshWriter<YaspGrid<2>::LeafGridView> amiramesh2d;
+  amiramesh2d.addUniformData(grid2d.leafGridView(), n2, vertexdata2d);
+  amiramesh2d.write("structuredgrid2d.am");
 
   // /////////////////////////////////////
   //   Test writing of 3d uniform grid
   // /////////////////////////////////////
-  SGrid<3,3> sgrid3d(n,h);
+
+  YaspGrid<3> grid3d({3.0, 2.0, 1.0}, { {10, 10, 10} });
 
   // create data buffer
-  std::vector<FieldVector<double,1> > vertexdata3d(sgrid3d.size(3));
+  std::vector<FieldVector<double,1> > vertexdata3d(grid3d.size(3));
 
-  SGrid<3,3>::Codim<3>::LeafIterator vIt    = sgrid3d.leafbegin<3>();
-  SGrid<3,3>::Codim<3>::LeafIterator vEndIt = sgrid3d.leafend<3>();
+  YaspGrid<3>::Codim<3>::LeafIterator vIt    = grid3d.leafbegin<3>();
+  YaspGrid<3>::Codim<3>::LeafIterator vEndIt = grid3d.leafend<3>();
 
   for (; vIt!=vEndIt; ++vIt)
-    vertexdata3d[sgrid3d.leafIndexSet().index(*vIt)] = vIt->geometry().corner(0).two_norm();
+    vertexdata3d[grid3d.leafIndexSet().index(*vIt)] = vIt->geometry().corner(0).two_norm();
 
   array<unsigned int, 3> n3;
   n3[0] = n[0]+1;
@@ -81,8 +82,8 @@ void testWritingUniformData() {
   n3[2] = n[2]+1;
 
   // write data
-  AmiraMeshWriter<SGrid<3,3>::LeafGridView> amiramesh3d;
-  amiramesh3d.addUniformData(sgrid3d.leafView(), n3, vertexdata3d);
+  AmiraMeshWriter<YaspGrid<3>::LeafGridView> amiramesh3d;
+  amiramesh3d.addUniformData(grid3d.leafGridView(), n3, vertexdata3d);
   amiramesh3d.write("sgrid3d.am");
 
 }
@@ -104,14 +105,14 @@ int main() try {
 #endif
 
 #if HAVE_ALUGRID
-  std::cout << "reading ALUSimplexGrid<2,2>" << std::endl;
-  testReadingUnstructuredGrid<ALUSimplexGrid<2,2> >(std::string(DUNE_GRID_EXAMPLE_GRIDS_PATH) + "amiramesh/simplex-testgrid-2d.am");
+  std::cout << "reading ALUGrid<2,2,simplex,nonconforming>" << std::endl;
+  testReadingUnstructuredGrid<ALUGrid<2,2,simplex,nonconforming> >(std::string(DUNE_GRID_EXAMPLE_GRIDS_PATH) + "amiramesh/simplex-testgrid-2d.am");
 
-  std::cout << "reading ALUSimplexGrid<3,3>" << std::endl;
-  testReadingUnstructuredGrid<ALUSimplexGrid<3,3> >(std::string(DUNE_GRID_EXAMPLE_GRIDS_PATH) + "amiramesh/simplex-testgrid-3d.am");
+  std::cout << "reading ALUGrid<3,3,simplex,nonconforming>" << std::endl;
+  testReadingUnstructuredGrid<ALUGrid<3,3,simplex,nonconforming> >(std::string(DUNE_GRID_EXAMPLE_GRIDS_PATH) + "amiramesh/simplex-testgrid-3d.am");
 
-  std::cout << "reading ALUCubeGrid<3,3>" << std::endl;
-  testReadingUnstructuredGrid<ALUCubeGrid<3,3> >(std::string(DUNE_GRID_EXAMPLE_GRIDS_PATH) + "amiramesh/cube-testgrid-3d.am");
+  std::cout << "reading ALUGrid<3,3,cube,nonconforming>" << std::endl;
+  testReadingUnstructuredGrid<ALUGrid<3,3,cube,nonconforming> >(std::string(DUNE_GRID_EXAMPLE_GRIDS_PATH) + "amiramesh/cube-testgrid-3d.am");
 #endif
 
   // Test whether writing uniform data works
