@@ -1,6 +1,8 @@
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 
+#define DISABLE_DEPRECATED_METHOD_CHECK 1
+
 #include <config.h>
 
 #include <string>
@@ -9,13 +11,13 @@
 
 #include <dune/grid/uggrid.hh>
 #include <dune/grid/io/file/starcdreader.hh>
-#include <dune/grid/test/gridcheck.cc>
+#include <dune/grid/test/gridcheck.hh>
 
 template <class GridType>
 void readGrid (const std::string& baseName)
 {
   // read the grid
-  std::auto_ptr<GridType> grid(Dune::StarCDReader<GridType>::read(baseName));
+  std::unique_ptr<GridType> grid(Dune::StarCDReader<GridType>::read(baseName));
 
   std::cout << "Starting grid tests ." << std::flush;
 
