@@ -156,7 +156,7 @@ namespace Dune
         if( intersection.neighbor() )
         {
           if( intersection.outside()->partitionType() != InteriorEntity )
-            he->bnd[ number ] = 2*(Entity :: dimensionworld) + (number+1);
+            he->bnd[ number ] = 2*(Entity :: Geometry :: dimensionworld) + (number+1);
         }
         lastElNum = number;
       }
@@ -169,12 +169,9 @@ namespace Dune
   el_update_base (Entity& en, DUNE_ELEM * he)
   {
     typedef typename Entity::Geometry DuneGeometryType;
-    typedef typename DuneGeometryType :: ctype ctype;
-
     enum { dim      = Entity::dimension };
-    enum { dimworld = Entity::dimensionworld };
 
-    typedef FieldVector<ctype, dimworld> CoordinateType;
+    typedef typename DuneGeometryType :: GlobalCoordinate CoordinateType;
 
     const DuneGeometryType &geometry = en.geometry();
 
@@ -193,7 +190,7 @@ namespace Dune
 
     // number of corners and number of vertices schould be the same
     // grape visual does not work for other situations
-    assert( en.template count<dim>() == geometry.corners() );
+    assert( int(en.subEntities( dim )) == int(geometry.corners()) );
     assert( geometry.corners() <= MAX_EL_DOF );
 
     for( int i = 0; i < geometry.corners(); ++i )
@@ -201,9 +198,9 @@ namespace Dune
       const int grapeVx = mapDune2GrapeVertex( geomType, i );
       he->vindex[ i ] = this->vertexIndex( indexSet_, en, grapeVx );
 
-      assert( Entity::dimensionworld <= 3 );
+      assert( DuneGeometryType::dimensionworld <= 3 );
       const CoordinateType coord = geometry.corner( grapeVx );
-      for( int j = 0; j < Entity::dimensionworld ; ++j )
+      for( int j = 0; j < DuneGeometryType::dimensionworld ; ++j )
       {
         // here the mapping from dune to grape elements is done
         // it's only different for quads and hexas
@@ -219,12 +216,9 @@ namespace Dune
   {
     typedef typename GridType::Traits::template Codim<0>::Entity Entity;
     typedef typename Entity::Geometry DuneGeometryType;
-    typedef typename DuneGeometryType :: ctype ctype;
 
     enum { dim      = Entity::dimension };
-    enum { dimworld = Entity::dimensionworld };
-
-    typedef FieldVector<ctype, dimworld> CoordinateType;
+    enum { dimworld = DuneGeometryType::dimensionworld };
 
     const Entity &en = (*it[0]);
 
@@ -643,14 +637,17 @@ namespace Dune
   inline void GrapeGridDisplay<GridType>::
   local_to_world(const EntityType &en, const double * c, double * w)
   {
+    typedef typename EntityType::Geometry DuneGeometryType;
     const int dim = EntityType::dimension;
-    const int dimworld = EntityType::dimensionworld;
+    const int dimworld = DuneGeometryType::dimensionworld;
 
     FieldVector< double, dim > local;
     for( int i = 0; i < dim; ++i )
       local[ i ] = c[ i ];
 
-    FieldVector< double, dimworld > global = en.geometry().global( local );
+    DuneGeometryType geometry = en.geometry();
+
+    FieldVector< double, dimworld > global = geometry.global( local );
     for( int i = 0; i < dimworld; ++i )
       w[ i ] = global[ i ];
   }
@@ -673,10 +670,12 @@ namespace Dune
   inline int GrapeGridDisplay< GridType >
   ::world_to_local( const Entity &entity, const double *w, double *c )
   {
-    const int dim = Entity::dimension;
-    const int dimworld = Entity::dimensionworld;
+    typedef typename Entity::Geometry DuneGeometryType;
 
-    const typename Entity::Geometry &geometry = entity.geometry();
+    const int dim = Entity::dimension;
+    const int dimworld = DuneGeometryType::dimensionworld;
+
+    DuneGeometryType geometry = entity.geometry();
 
     FieldVector< double, dimworld > global;
     for( int i = 0; i < dimworld; ++i )
