@@ -1,10 +1,12 @@
+// -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
+// vi: set et ts=4 sw=2 sts=2:
 /*
  * grape-module "level_disp.c"
  *
  * Description       : shrink-display-method on hmesh3d,
  *                     uses displays every partition in different color
  *
- * Author            : Dirk Trescher, Robert K. 
+ * Author            : Dirk Trescher, Robert K.
  *
  */
 #ifndef __GRAPE_PARTITIONDISPLAY_HH_
@@ -28,7 +30,7 @@ static int light_on = TRUE;
 static int bar_on = TRUE;
 static int diag_on = FALSE;
 
-#define NUM_OF_COLORS 32 
+#define NUM_OF_COLORS 32
 
 static VEC3 color[NUM_OF_COLORS];
 
@@ -36,60 +38,56 @@ static BUTTON*  light_ctl = NULL;
 static BUTTON*  bar_ctl = NULL;
 static BUTTON*  diagnostic_ctl = NULL;
 
-static int  last_element; /*  merkt sich das letzte El in der display-Routine  */
-static int  last_partition; /*  true wenn wir auf der letzten partition arbeiten */
-static int  max_partition = 1; /* max number of partitions */
-static int  thread = 0; /* actual partition number */
+static int last_element;  /*  merkt sich das letzte El in der display-Routine  */
+static int last_partition;  /*  true wenn wir auf der letzten partition arbeiten */
+static int max_partition = 1;  /* max number of partitions */
+static int thread = 0;  /* actual partition number */
 
-static SUPROP_DEV  suprop;
+static SUPROP_DEV suprop;
 
 /*  ------------------------------------------------------------------  */
 
 inline GENMESHnD* genmesh3d_switch_part_light_model_on_off ()
-{ 
+{
   GENMESHnD*          hmesh = (GENMESHnD*) START_METHOD (G_INSTANCE);
   GRAPE_ALERT (hmesh, "genmesh3d-switch-part-light-model-on-off: No hmesh!", END_METHOD(NULL));
 
-  if( light_on )
-  { light_on = FALSE;
-    GRAPE_CALL(light_ctl,"set-state")(PRESSED);
+  if( light_on ) {
+    light_on = FALSE;
+    GRAPE_CALL(light_ctl,"set-state") (PRESSED);
+  } else {
+    light_on = TRUE;
+    GRAPE_CALL(light_ctl,"set-state") (UNPRESSED);
   }
-  else
-  { light_on = TRUE;
-    GRAPE_CALL(light_ctl,"set-state")(UNPRESSED);
-  }
-
   END_METHOD (hmesh);
 }
 
 inline GENMESHnD* genmesh3d_switch_part_diagnostic_on_off ()
-{ 
+{
   GENMESHnD*   hmesh = (GENMESHnD*) START_METHOD (G_INSTANCE);
   GRAPE_ALERT (hmesh, "genmesh3d-switch-part-diagnostic-on-off: No hmesh!", END_METHOD(NULL));
 
-  if( diag_on )
-  { diag_on = FALSE;
-    GRAPE_CALL(diagnostic_ctl,"set-state")(PRESSED);
-  }
-  else
-  { diag_on = TRUE;
-    GRAPE_CALL(diagnostic_ctl,"set-state")(UNPRESSED);
+  if( diag_on ) {
+    diag_on = FALSE;
+    GRAPE_CALL(diagnostic_ctl,"set-state") (PRESSED);
+  } else {
+    diag_on = TRUE;
+    GRAPE_CALL(diagnostic_ctl,"set-state") (UNPRESSED);
   }
   END_METHOD (hmesh);
 }
 
 inline GENMESHnD* genmesh3d_switch_part_displaybar_on_off ()
-{ 
+{
   GENMESHnD*   hmesh = (GENMESHnD*) START_METHOD (G_INSTANCE);
   GRAPE_ALERT (hmesh, "genmesh3d-switch-part-displaybar-on-off: No hmesh!", END_METHOD(NULL));
 
-  if( bar_on )
-  { bar_on = FALSE;
-    GRAPE_CALL(bar_ctl,"set-state")(PRESSED);
-  }
-  else
-  { bar_on = TRUE;
-    GRAPE_CALL(bar_ctl,"set-state")(UNPRESSED);
+  if( bar_on ) {
+    bar_on = FALSE;
+    GRAPE_CALL(bar_ctl,"set-state") (PRESSED);
+  } else {
+    bar_on = TRUE;
+    GRAPE_CALL(bar_ctl,"set-state") (UNPRESSED);
   }
   END_METHOD (hmesh);
 }
@@ -114,16 +112,16 @@ static double maxTime = 200;
 static int * globalLastStep = 0 ;
 
 static GRAPHICDEVICE * dev = 0 ;
-static double           colorbarHeight = 1.8, colorbarWidth = 0.07,
-                        colorbarBoundingScale = 0.1 ;
-static double           colorbarX = -0.75, colorbarY = -0.9 , colorbarZ = 0.9 ;
-static void     (*patch_normal)(const double *), 
-                (*patch_color) (const double *), 
-                (*patch_vertex)(const double *),
-                (*begin_patch)(), (*end_patch)(),
-                (*move)(const double *), 
-                (*draw)(const double *), 
-                (*text)(const double*, const char*);
+static double colorbarHeight = 1.8, colorbarWidth = 0.07,
+              colorbarBoundingScale = 0.1 ;
+static double colorbarX = -0.75, colorbarY = -0.9 , colorbarZ = 0.9 ;
+static void (*patch_normal)(const double *),
+(*patch_color)(const double *),
+(*patch_vertex)(const double *),
+(*begin_patch)(), (*end_patch)(),
+(*move)(const double *),
+(*draw)(const double *),
+(*text)(const double*, const char*);
 
 static int initColorBarDone = 0;
 
@@ -131,7 +129,7 @@ static inline void set_colors (int currProcs);
 
 inline static void get_graphicdevice()
 {
-  dev = (GRAPHICDEVICE *)GRAPE_CALL(GraphicDevice,"get-stddev")();
+  dev = (GRAPHICDEVICE *)GRAPE_CALL(GraphicDevice,"get-stddev") ();
 
   patch_normal = dev->patch_normal;
   patch_color  = dev->patch_color;
@@ -148,11 +146,11 @@ static void setThread( int t )
   thread = t;
 }
 
-inline void initColorBarDisp() 
+inline void initColorBarDisp()
 {
   int i ;
   assert (max_partition >= 0) ;
-  printf("Init ColorBar for %d partitions!\n", max_partition ); 
+  printf("Init ColorBar for %d partitions!\n", max_partition );
   if(!globalNumberOfElements) globalNumberOfElements = (int *) malloc (sizeof(int) * max_partition) ;
   if(!globalLastStep) globalLastStep = (int *) malloc (sizeof(int) * max_partition) ;
   for (i = 0 ; i < max_partition ; i ++) globalLastStep [i] = -1 ;
@@ -165,9 +163,9 @@ inline void initColorBarDisp()
 
 inline static void colorbar_display(int nProcs)
 {
-  int       i, light_model, off = OFF,totalnoElements;
-  VEC3      xyz, xyz_g, back_color = { 0.3, 0.3, 0.3 };
-  MATRIX44        matp, matv, matm, mat;
+  int i, light_model, off = OFF,totalnoElements;
+  VEC3 xyz, xyz_g, back_color = { 0.3, 0.3, 0.3 };
+  MATRIX44 matp, matv, matm, mat;
 
   dev->attribute(G_MODE_GET,G_LIGHT_MODEL,&light_model);
   dev->attribute(G_MODE_SET,G_LIGHT_MODEL,&off);
@@ -177,7 +175,7 @@ inline static void colorbar_display(int nProcs)
   dev->transform(G_MODE_GET,G_MATRIX_VIEW,matv);
   dev->transform(G_MODE_GET,G_MATRIX_PROJECT,matp);
   /*dev->attribute(G_MODE_GET, G_FONT, oldfont);
-  printf("%s\n",oldfont);*/
+     printf("%s\n",oldfont);*/
 
   g_matrix44_set_identity (mat);
   dev->transform(G_MODE_SET,G_MATRIX_PROJECT,mat);
@@ -208,7 +206,7 @@ inline static void colorbar_display(int nProcs)
   xyz_g[2] = colorbarZ;
 
   totalnoElements = 0;
-  
+
   for (i=0; i<nProcs; i++)
   {
     totalnoElements += globalNumberOfElements [i] ;
@@ -298,25 +296,25 @@ inline static void hsv_to_rgb (VEC3 rgb, VEC3 hsv)
     q = v*(1.-(s*f));
     t = v*(1.-(s*(1.-f)));
     switch (i) {
-    case 0:
+    case 0 :
       g_vec3_set (rgb, v,t,p);
       break;
-    case 1:
+    case 1 :
       g_vec3_set (rgb, q,v,p);
       break;
-    case 2:
+    case 2 :
       g_vec3_set (rgb, p,v,t);
       break;
-    case 3:
+    case 3 :
       g_vec3_set (rgb, p,q,v);
       break;
-    case 4:
+    case 4 :
       g_vec3_set (rgb, t,p,v);
       break;
-    case 5:
+    case 5 :
       g_vec3_set (rgb, v,p,q);
       break;
-    default:
+    default :
       g_vec3_set (rgb, 1.0, 1.0, 1.0);
       break;
     }
@@ -327,20 +325,20 @@ inline static void hsv_to_rgb (VEC3 rgb, VEC3 hsv)
 inline static void set_colors (int currProcs)
 {
   /*
-  for( i=0; i<max_partition+1; ++i )
-  { 
-    color[i][0] = color_intensity * G_MAX( G_MIN((-3.*i)/max_partition + 2., 1.), 0. );
-    color[i][1] = color_intensity * G_MIN( G_MIN(( 3.*i)/max_partition, 1.), (-6.*i)/max_partition + 6. );
-    color[i][2] = color_intensity * G_MIN( G_MAX(( 6.*i)/max_partition - 4., 0.), 1. );
-  }
-  */
+     for( i=0; i<max_partition+1; ++i )
+     {
+     color[i][0] = color_intensity * G_MAX( G_MIN((-3.*i)/max_partition + 2., 1.), 0. );
+     color[i][1] = color_intensity * G_MIN( G_MIN(( 3.*i)/max_partition, 1.), (-6.*i)/max_partition + 6. );
+     color[i][2] = color_intensity * G_MIN( G_MAX(( 6.*i)/max_partition - 4., 0.), 1. );
+     }
+   */
 
   if (currProcs == 1) {
     color [0][0] = color [0][1] = color [0][2] = 1.;
   } else {
-    int                  i, size = G_MIN(NUM_OF_COLORS,currProcs), mod = 1;
-    double               frac = 1.;
-    VEC3                 hsv, diff = {0., .3, .5};
+    int i, size = G_MIN(NUM_OF_COLORS,currProcs), mod = 1;
+    double frac = 1.;
+    VEC3 hsv, diff = {0., .3, .5};
 
     if (size >= 16)
       mod = 3;
@@ -362,45 +360,45 @@ inline static void set_colors (int currProcs)
     }
   }
   return ;
-} 
+}
 
 /* forward declaration */
 inline GENMESHnD* genmesh3d_partition_disp ();
 
 static int initialized = 0;
 /* init max_partition and declare partition methods */
-inline void initPartitionDisp (int mp) 
+inline void initPartitionDisp (int mp)
 {
   if(!initialized)
   {
     max_partition = mp;
-  
+
     printf("Add Method 'switch-part-light-model-on-off' on GenMesh3d!\n");
-    GRAPE_CALL(GenMesh3d,"add-method")("switch-part-light-model-on-off",genmesh3d_switch_part_light_model_on_off);
+    GRAPE_CALL(GenMesh3d,"add-method") ("switch-part-light-model-on-off",genmesh3d_switch_part_light_model_on_off);
 
     printf("Add Method 'switch-part-displaybar-on-off' on GenMesh3d!\n");
-    GRAPE_CALL(GenMesh3d,"add-method")("switch-part-displaybar-on-off",genmesh3d_switch_part_displaybar_on_off);
-    GRAPE_CALL(GenMesh3d,"add-method")("switch-part-diagnostic-on-off",genmesh3d_switch_part_diagnostic_on_off);
+    GRAPE_CALL(GenMesh3d,"add-method") ("switch-part-displaybar-on-off",genmesh3d_switch_part_displaybar_on_off);
+    GRAPE_CALL(GenMesh3d,"add-method") ("switch-part-diagnostic-on-off",genmesh3d_switch_part_diagnostic_on_off);
     printf("Add Method 'partition-disp' on GenMesh3d!\n");
-    GRAPE_CALL(GenMesh3d,"add-method")("partition-disp",genmesh3d_partition_disp);
+    GRAPE_CALL(GenMesh3d,"add-method") ("partition-disp",genmesh3d_partition_disp);
     printf("\n");
     initialized = 1;
   }
 }
 
 inline GENMESHnD* genmesh3d_partition_disp ()
-{  
+{
   MANAGER*             mgr;
   GRAPHICDEVICE*       dev;
   GENMESHnD*           hmesh;
   F_HDATA3D*           fhdata;
- 
+
   HM3_GENERAL*         general;
 
-  int                  i, max;
-  
+  int i, max;
+
   VEC3 save_color;
-  double transparency; 
+  double transparency;
 
   if(!initColorBarDone) initColorBarDisp();
 
@@ -408,82 +406,82 @@ inline GENMESHnD* genmesh3d_partition_disp ()
   static FUNCTION_SLIDER* shrink_size_ctl     = NULL;
   static FUNCTION_SLIDER* color_intensity_ctl = NULL;
   /* get hmesh */
-  
+
   hmesh = (GENMESHnD*) START_METHOD (G_INSTANCE);
   GRAPE_ALERT (hmesh, "genmesh3d-partition: No hmesh!", END_METHOD(NULL));
 
   fhdata = (F_HDATA3D*)GRAPE_CALL(hmesh,"get-function")
-    ("scalar","scalar","vector","default", NULL);
+             ("scalar","scalar","vector","default", NULL);
 
   set_colors( max_partition );
 
   /* GRAPE preliminaries */
   mgr = (MANAGER *)      GRAPE_CALL(Manager,       "get-stdmgr") ();
   dev = (GRAPHICDEVICE*) GRAPE_CALL(GraphicDevice, "get-stddev") ();
-    
+
 
   /* get interactives */
   if (!shrink_size_ctl) {
     shrink_size_ctl = (FUNCTION_SLIDER*) new_item (Function_Slider,
-      I_Label,   "shrink-factor",
-      I_Var,     &shrink_size, dfDouble,
-      I_MinMax,  0.01, 1.0,
-      I_Scale,   1.0,
-      I_Offset,  0.0,
-      I_RSizeX,  1.0, I_SizeY, 1.0,
-      I_End); 
+                                                   I_Label,   "shrink-factor",
+                                                   I_Var,     &shrink_size, dfDouble,
+                                                   I_MinMax,  0.01, 1.0,
+                                                   I_Scale,   1.0,
+                                                   I_Offset,  0.0,
+                                                   I_RSizeX,  1.0, I_SizeY, 1.0,
+                                                   I_End);
   }
   if (!color_intensity_ctl) {
     color_intensity_ctl = (FUNCTION_SLIDER*) new_item (Function_Slider,
-      I_Label,   "color intensity",
-      I_Var,     &color_intensity, dfDouble,
-      I_MinMax,  0.0, 1.0,
-      I_Scale,   1.0,
-      I_Offset,  0.0,
-      I_RSizeX,  1.0, I_SizeY, 1.0,
-      I_End); 
+                                                       I_Label,   "color intensity",
+                                                       I_Var,     &color_intensity, dfDouble,
+                                                       I_MinMax,  0.0, 1.0,
+                                                       I_Scale,   1.0,
+                                                       I_Offset,  0.0,
+                                                       I_RSizeX,  1.0, I_SizeY, 1.0,
+                                                       I_End);
   }
   if (!light_ctl) {
     light_ctl = (BUTTON*) new_item (Button,
-      I_Label,   "light model",
-      I_State,   PRESSED,
-      I_Instance, hmesh,
-      I_Method,  "switch-part-light-model-on-off",
-      I_RSizeX,  1.0, I_SizeY, 1.0,
-      I_End);
+                                    I_Label,   "light model",
+                                    I_State,   PRESSED,
+                                    I_Instance, hmesh,
+                                    I_Method,  "switch-part-light-model-on-off",
+                                    I_RSizeX,  1.0, I_SizeY, 1.0,
+                                    I_End);
   }
 
   if (!bar_ctl) {
     bar_ctl = (BUTTON*) new_item (Button,
-      I_Label,   "display partition bar",
-      I_State,   PRESSED,
-      I_Instance, hmesh,
-      I_Method,  "switch-part-displaybar-on-off",
-      I_RSizeX,  1.0, I_SizeY, 1.0,
-      I_End);
+                                  I_Label,   "display partition bar",
+                                  I_State,   PRESSED,
+                                  I_Instance, hmesh,
+                                  I_Method,  "switch-part-displaybar-on-off",
+                                  I_RSizeX,  1.0, I_SizeY, 1.0,
+                                  I_End);
   }
 
   if (!diagnostic_ctl) {
     diagnostic_ctl = (BUTTON*) new_item (Button,
-      I_Label,   "diagnostics ",
-      I_State,   UNPRESSED,
-      I_Instance, hmesh,
-      I_Method,  "switch-part-diagnostic-on-off",
-      I_RSizeX,  1.0, I_SizeY, 1.0,
-      I_End);
+                                         I_Label,   "diagnostics ",
+                                         I_State,   UNPRESSED,
+                                         I_Instance, hmesh,
+                                         I_Method,  "switch-part-diagnostic-on-off",
+                                         I_RSizeX,  1.0, I_SizeY, 1.0,
+                                         I_End);
   }
 
   if (!group) {
     group = (GROUP*) new_item (Group,
-      I_Border,  bfBorder|bfTitle,
-      I_Name,    "genmesh3d-partition",
-      I_Size,    12.0, 1.1+5.*1.07,
-      I_Item,    light_ctl,
-      I_Item,    bar_ctl,
-      I_Item,    diagnostic_ctl,
-      I_Item,    color_intensity_ctl,
-      I_Item,    shrink_size_ctl,
-      I_End);
+                               I_Border,  bfBorder|bfTitle,
+                               I_Name,    "genmesh3d-partition",
+                               I_Size,    12.0, 1.1+5.*1.07,
+                               I_Item,    light_ctl,
+                               I_Item,    bar_ctl,
+                               I_Item,    diagnostic_ctl,
+                               I_Item,    color_intensity_ctl,
+                               I_Item,    shrink_size_ctl,
+                               I_End);
   }
 
   if (GRAPE_CALL(mgr,"new-handle") (genmesh3d_partition_disp,1)) {
@@ -493,20 +491,20 @@ inline GENMESHnD* genmesh3d_partition_disp ()
   last_element = -1;
   last_partition = 0;
 
-  GRAPE_CALL(hmesh,"get-partition-number")(&thread);
+  GRAPE_CALL(hmesh,"get-partition-number") (&thread);
   if(thread == max_partition-1) last_partition = 1;
 
   /*  Surface-Properties holen  */
-  dev->attribute (G_MODE_GET, G_PATCH_SUPROP, &suprop);   
-          
+  dev->attribute (G_MODE_GET, G_PATCH_SUPROP, &suprop);
+
   /* prepare mesh-traverse */
-  max = hmesh->level_of_interest + 1; 
- 
+  max = hmesh->level_of_interest + 1;
+
   general = (HM3_GENERAL*) GRAPE_CALL(hmesh, "general-alloc") (TRUE);
   general->f_data3d = fhdata;
 
   //G_MEM_ALLOC(hm3_partition_data,max);
-  HM3_COORD_DATA** hm3_partition_data = (HM3_COORD_DATA**) std::malloc((max)*sizeof(*(hm3_partition_data))); 
+  HM3_COORD_DATA** hm3_partition_data = (HM3_COORD_DATA**) std::malloc((max)*sizeof(*(hm3_partition_data)));
 
   for (i=0; i<max; i++) { G_MEM_ALLOC(hm3_partition_data[i],1); }
 
@@ -516,19 +514,19 @@ inline GENMESHnD* genmesh3d_partition_disp ()
   transparency = suprop.transparency;
 
   /* traverse the mesh */
-#if GRAPE_DIM == 3 
+#if GRAPE_DIM == 3
   g_traverse_mesh3d (hmesh,
-          general,
-          G_LEAVES,
-          hmesh->level_of_interest,
-          hm3_simpl_projection,
-          hm3_simpl_test_if_proceed,
-          hm3_partition_draw_element,
-          (void**) hm3_partition_data,
-          NULL,
-          hefAll);
+                     general,
+                     G_LEAVES,
+                     hmesh->level_of_interest,
+                     hm3_simpl_projection,
+                     hm3_simpl_test_if_proceed,
+                     hm3_partition_draw_element,
+                     (void**) hm3_partition_data,
+                     NULL,
+                     hefAll);
 #endif
-  
+
   for(i=0; i<max; i++) { G_MEM_FREE(hm3_partition_data[i],1); }
 
   suprop.emission[0] = save_color[0];
@@ -537,35 +535,35 @@ inline GENMESHnD* genmesh3d_partition_disp ()
   suprop.transparency = transparency;
   dev->attribute (G_MODE_SET, G_PATCH_SUPROP, &suprop);
 
-  if(last_partition && bar_on ) 
+  if(last_partition && bar_on )
     colorbar_display(max_partition);
-  else if (last_partition) 
+  else if (last_partition)
     for(i=0; i<max_partition; i++) globalNumberOfElements [i] = 0;
- 
+
   std::free(hm3_partition_data);
   //G_MEM_FREE (hm3_partition_data,max);
   END_METHOD (hmesh);
 }
 
 inline static int hm3_partition_draw_element (HELEMENT3D* helement,
-  HM3_GENERAL* general, void* el_data, void* action_arg)
+                                              HM3_GENERAL* general, void* el_data, void* action_arg)
 {
   GRAPHICDEVICE*          dev   = general->dev;
   HELEMENT3D_DESCRIPTION* descr = (HELEMENT3D_DESCRIPTION*) helement->descr;
   HM3_COORD_DATA*  element_data = (HM3_COORD_DATA*)         el_data;
 
   VEC3* vertex_coord = element_data->vertex_coord;
-  VEC3  shrinked_coord [MESH3D_MAX_VERTEX];
-  VEC3  normal;
-  VEC3  center;
-  
-  int        h, i;
+  VEC3 shrinked_coord [MESH3D_MAX_VERTEX];
+  VEC3 normal;
+  VEC3 center;
+
+  int h, i;
 
   /* count elements of partition */
   globalNumberOfElements [thread]++;
 
   g_vec3_set_zero (center);
-  
+
   for (i=0; i<descr->number_of_vertices; i++ ) {
     center[0] += vertex_coord[i][0];
     center[1] += vertex_coord[i][1];
@@ -576,19 +574,19 @@ inline static int hm3_partition_draw_element (HELEMENT3D* helement,
   center[1] /= descr->number_of_vertices;
   center[2] /= descr->number_of_vertices;
 
-  /* draw each face of the element seperately */
+  /* draw each face of the element separately */
   for (h=0; h<descr->number_of_polygons; h++) {
 
     /* calculate shrinked coordinates */
     for (i=0; i<descr->polygon_length[h]; i++) {
       shrinked_coord[i][0] = (1.0 - shrink_size) * center[0]
-        + shrink_size * vertex_coord [descr->polygon_vertex[h][i]] [0];
+                             + shrink_size * vertex_coord [descr->polygon_vertex[h][i]] [0];
       shrinked_coord[i][1] = (1.0 - shrink_size) * center[1]
-        + shrink_size * vertex_coord [descr->polygon_vertex[h][i]] [1];
+                             + shrink_size * vertex_coord [descr->polygon_vertex[h][i]] [1];
       shrinked_coord[i][2] = (1.0 - shrink_size) * center[2]
-        + shrink_size * vertex_coord [descr->polygon_vertex[h][i]] [2];
+                             + shrink_size * vertex_coord [descr->polygon_vertex[h][i]] [2];
     }
-  
+
     /* draw one face as grip or patch */
     if (dev->grid_patch == G_GRID) {
       VEC3 linecolor;
@@ -598,7 +596,7 @@ inline static int hm3_partition_draw_element (HELEMENT3D* helement,
 
       dev->move (shrinked_coord[descr->polygon_length[h]-1]);
 
-      for (i=0; i<descr->polygon_length[h]; i++){
+      for (i=0; i<descr->polygon_length[h]; i++) {
         dev->draw (shrinked_coord[i]);
       }
       dev->attribute (G_MODE_SET, G_LINE_COLOR, linecolor);
@@ -607,11 +605,10 @@ inline static int hm3_partition_draw_element (HELEMENT3D* helement,
       int light_model, off = 0;
 
       g_vec3_get_normal_to_plane (normal,
-        shrinked_coord[0], shrinked_coord[1], shrinked_coord[2]);
+                                  shrinked_coord[0], shrinked_coord[1], shrinked_coord[2]);
 
-      if( light_on )
-      { if( thread != last_element )
-        { 
+      if( light_on ) {
+        if( thread != last_element ) {
           suprop.emission[0] = color[thread][0];
           suprop.emission[1] = color[thread][1];
           suprop.emission[2] = color[thread][2];
@@ -620,9 +617,8 @@ inline static int hm3_partition_draw_element (HELEMENT3D* helement,
 
           last_element = thread;
         }
-      }
-      else
-      { dev->attribute (G_MODE_GET, G_LIGHT_MODEL, &light_model);
+      } else {
+        dev->attribute (G_MODE_GET, G_LIGHT_MODEL, &light_model);
         dev->attribute (G_MODE_SET, G_LIGHT_MODEL, &off);
       }
 
@@ -630,11 +626,11 @@ inline static int hm3_partition_draw_element (HELEMENT3D* helement,
       if( !light_on )
         dev->patch_color (color[thread]);
       dev->patch_normal (normal);
-    
+
       for (i=0; i<descr->polygon_length[h]; i++) {
         dev->patch_vertex (shrinked_coord[i]);
-      }  
-    
+      }
+
       dev->end_patch ();
 
       if( !light_on )
@@ -642,46 +638,46 @@ inline static int hm3_partition_draw_element (HELEMENT3D* helement,
     }
   }
   return TRUE;
-}    
+}
 
 
 inline int hm3_simpl_projection (HELEMENT3D*  helement,
-        HM3_GENERAL* general,
-        void*        el_data,
-        void*        pa_data)
-{ 
+                                 HM3_GENERAL* general,
+                                 void*        el_data,
+                                 void*        pa_data)
+{
   HM3_COORD_DATA* element_data = (HM3_COORD_DATA*)el_data;
   HM3_COORD_DATA* parent_data  = (HM3_COORD_DATA*)pa_data;
-  
+
   VEC3* vertex_coord = element_data->vertex_coord;
 
   MAKE_SIMPL_PROJECT (3, helement,
-            parent_data,
-          {
-            g_vec3_assign (vertex_coord[local_node_number],
-               helement->vertex[local_node_number]);
-          },
-          {
-      g_vec3_hm_interpol (helement,
-              vertex_coord[local_node_number],
-              parent_data->vertex_coord,
-              local_node_number);
-          },
-          {
-      g_vec3_assign (vertex_coord[local_node_number],
-               parent_data->vertex_coord[helement->
-                 vinh[local_node_number].pindex[0]]);
-          }, 
-          TRUE, return FALSE);
+                      parent_data,
+                      {
+                        g_vec3_assign (vertex_coord[local_node_number],
+                                       helement->vertex[local_node_number]);
+                      },
+                      {
+                        g_vec3_hm_interpol (helement,
+                                            vertex_coord[local_node_number],
+                                            parent_data->vertex_coord,
+                                            local_node_number);
+                      },
+                      {
+                        g_vec3_assign (vertex_coord[local_node_number],
+                                       parent_data->vertex_coord[helement->
+                                                                 vinh[local_node_number].pindex[0]]);
+                      },
+                      TRUE, return FALSE);
   return TRUE;
 }
 
 inline int hm3_simpl_test_if_proceed  (HELEMENT3D*  helement,
-             HM3_GENERAL* general,
-             void*        el_data)
+                                       HM3_GENERAL* general,
+                                       void*        el_data)
 {
   int result;
-  
+
   HM_TEST_IF_PROCEED(3,result, helement, general);
 
   return result;
