@@ -101,12 +101,18 @@ namespace Dune {
     return SUnitCubeMapper<dim>::mapper.elements(cc);
   }
 
+  template<int dim, class GridImp>
+  inline unsigned int SEntity<0,dim,GridImp>::subEntities (unsigned int codim) const
+  {
+    return SUnitCubeMapper<dim>::mapper.elements(codim);
+  }
+
   // subentity construction
   template<int dim, class GridImp> template<int cc>
-  inline typename SEntity<0,dim,GridImp>::template Codim<cc>::EntityPointer SEntity<0,dim,GridImp>::subEntity (int i) const
+  inline typename SEntity<0,dim,GridImp>::template Codim<cc>::Entity SEntity<0,dim,GridImp>::subEntity (int i) const
   {
     // make Iterator
-    return SLevelIterator<cc,All_Partition,const GridImp>(this->grid,this->l,this->subCompressedIndex(cc,i));
+    return SLevelIterator<cc,All_Partition,const GridImp>(this->grid,this->l,this->subCompressedIndex(cc,i)).dereference();
   }
 
   template<int dim, class GridImp>
@@ -189,13 +195,13 @@ namespace Dune {
   }
 
   template<int dim, class GridImp>
-  inline typename SEntity<0,dim,GridImp>::EntityPointer SEntity<0,dim,GridImp>::father () const
+  inline typename SEntity<0,dim,GridImp>::Entity SEntity<0,dim,GridImp>::father () const
   {
     if (!built_father) make_father();
     if (this->l>0)
-      return SLevelIterator<0,All_Partition,const GridImp>((this->grid),(this->l)-1,father_index);
+      return SLevelIterator<0,All_Partition,const GridImp>((this->grid),(this->l)-1,father_index).dereference();
     else
-      return SLevelIterator<0,All_Partition,const GridImp>((this->grid),this->l,index);
+      return SLevelIterator<0,All_Partition,const GridImp>((this->grid),this->l,index).dereference();
   }
 
   template<int dim, class GridImp>
@@ -275,7 +281,17 @@ namespace Dune {
   // inline methods for IntersectionIterator
 
   template<class GridImp>
-  void SIntersectionIterator<GridImp>::make (int _count) const
+  inline void SIntersectionIterator<GridImp>::increment ()
+  {
+    GridImp::getRealImplementation(intersection).count++;
+    GridImp::getRealImplementation(intersection).make(GridImp::getRealImplementation(intersection).count);
+  }
+
+  //************************************************************************
+  // inline methods for Intersection
+
+  template<class GridImp>
+  void SIntersection<GridImp>::make (int _count) const
   {
     // reset cache flags
     built_intersections = false;
@@ -286,9 +302,9 @@ namespace Dune {
     count = _count;
 
     // check if count is valid
-    if (count<0 || count>=grid->getRealImplementation(self).entity().template count<1>())
+    if (count<0 || count>=int(grid->getRealImplementation(self).subEntities(1)))
     {
-      grid->getRealImplementation(ne).index = -1;
+      // grid->getRealImplementation(ne).index = -1; // yes, this kills debugging code, but SGrid is dying anyway...
       return;   // done, this is end iterator
     }
     valid_count = true;
@@ -298,62 +314,55 @@ namespace Dune {
     zrednb[count/2] += -1+2*(count%2); // (count%2) ? +1 : -1
 
     // now check if neighbor exists
-    is_on_boundary = !grid->exists(grid->getRealImplementation(self).l,zrednb);
+    is_on_boundary = !grid->exists(grid->getRealImplementation(self).level(),zrednb);
     if (is_on_boundary)
     {
-      grid->getRealImplementation(ne).index = -1;
+      // grid->getRealImplementation(ne).index = -1; // again, kill debugging code...
       return;   // ok, done it
     }
 
     // now neighbor is in the grid and must be initialized.
     // First compute its index
-    grid->getRealImplementation(ne).index =
-      grid->n(grid->getRealImplementation(self).l,
-              grid->expand(grid->getRealImplementation(self).l,zrednb,partition));
-    grid->getRealImplementation(ne).realEntity().make(
-      grid->getRealImplementation(ne).l,
-      grid->getRealImplementation(ne).index);
+    auto index =
+      grid->n(grid->getRealImplementation(self).level(),
+              grid->expand(grid->getRealImplementation(self).level(),zrednb,partition));
+    grid->getRealImplementation(ne).make(
+      grid->getRealImplementation(ne).level(),
+      index);
   }
 
   template<class GridImp>
-  inline bool SIntersectionIterator<GridImp>::equals (const SIntersectionIterator<GridImp>& i) const
+  inline bool SIntersection<GridImp>::equals (const SIntersection<GridImp>& i) const
   {
     return (self == i.self) && (count==i.count);
   }
 
   template<class GridImp>
-  inline typename SIntersectionIterator<GridImp>::EntityPointer SIntersectionIterator<GridImp>::inside () const
+  inline typename SIntersection<GridImp>::Entity SIntersection<GridImp>::inside () const
   {
     return self;
   }
 
   template<class GridImp>
-  inline typename SIntersectionIterator<GridImp>::EntityPointer SIntersectionIterator<GridImp>::outside () const
+  inline typename SIntersection<GridImp>::Entity SIntersection<GridImp>::outside () const
   {
     return ne;
   }
 
   template<class GridImp>
-  inline void SIntersectionIterator<GridImp>::increment ()
-  {
-    count++;
-    make(count);
-  }
-
-  template<class GridImp>
-  inline bool SIntersectionIterator<GridImp>::boundary () const
+  inline bool SIntersection<GridImp>::boundary () const
   {
     return is_on_boundary;
   }
 
   template<class GridImp>
-  inline bool SIntersectionIterator<GridImp>::neighbor () const
+  inline bool SIntersection<GridImp>::neighbor () const
   {
     return (!is_on_boundary);
   }
 
   template<class GridImp>
-  void SIntersectionIterator<GridImp>::makeintersections () const
+  void SIntersection<GridImp>::makeintersections () const
   {
     // compute direction and value in direction
     int dir = count/2;
@@ -361,7 +370,7 @@ namespace Dune {
 
     // compute expanded coordinates of entity
     array<int,dim> z1 =
-      grid->getRealImplementation(grid->getRealImplementation(self).entity()).z;
+      grid->getRealImplementation(self).z;
     if (c==1)
       z1[dir] += 1;   // odd
     else
@@ -432,8 +441,8 @@ namespace Dune {
   }
 
   template<class GridImp>
-  inline typename SIntersectionIterator< GridImp >::LocalGeometry
-  SIntersectionIterator< GridImp >::geometryInInside () const
+  inline typename SIntersection< GridImp >::LocalGeometry
+  SIntersection< GridImp >::geometryInInside () const
   {
     assert (valid_count);
     if (!built_intersections) makeintersections();
@@ -441,8 +450,8 @@ namespace Dune {
   }
 
   template<class GridImp>
-  inline typename SIntersectionIterator< GridImp >::LocalGeometry
-  SIntersectionIterator< GridImp >::geometryInOutside () const
+  inline typename SIntersection< GridImp >::LocalGeometry
+  SIntersection< GridImp >::geometryInOutside () const
   {
     assert (valid_count);
     if (!built_intersections) makeintersections();
@@ -450,8 +459,8 @@ namespace Dune {
   }
 
   template<class GridImp>
-  inline typename SIntersectionIterator< GridImp >::Geometry
-  SIntersectionIterator< GridImp >::geometry () const
+  inline typename SIntersection< GridImp >::Geometry
+  SIntersection< GridImp >::geometry () const
   {
     assert (valid_count);
     if (!built_intersections) makeintersections();
@@ -459,13 +468,13 @@ namespace Dune {
   }
 
   template<class GridImp>
-  inline int SIntersectionIterator<GridImp>::indexInInside () const
+  inline int SIntersection<GridImp>::indexInInside () const
   {
     return count;
   }
 
   template<class GridImp>
-  inline int SIntersectionIterator<GridImp>::indexInOutside () const
+  inline int SIntersection<GridImp>::indexInOutside () const
   {
     return (count/2)*2 + (1-count%2);
   }
@@ -508,7 +517,7 @@ namespace Dune {
   inline void SGrid<dim,dimworld,ctype>::makeSGrid (const array<int,dim>& N_,
                                                     const FieldVector<ctype,dim>& L_, const FieldVector<ctype,dim>& H_)
   {
-    dune_static_assert(dimworld <= std::numeric_limits<int>::digits,"world dimension too high, must be <= # of bits of int");
+    static_assert(dimworld <= std::numeric_limits<int>::digits,"world dimension too high, must be <= # of bits of int");
 
 #ifndef NDEBUG
     bool correct = true;
@@ -565,7 +574,7 @@ namespace Dune {
   template<int dim, int dimworld, typename ctype>
   inline SGrid<dim,dimworld,ctype>::SGrid (const int * const N_, const ctype * const H_)
   {
-    dune_static_assert(dimworld <= std::numeric_limits<int>::digits,"world dimension too high, must be <= # of bits of int");
+    static_assert(dimworld <= std::numeric_limits<int>::digits,"world dimension too high, must be <= # of bits of int");
 
     array<int,dim> N;
     FieldVector<ctype,dim> L(0.0);
@@ -579,7 +588,7 @@ namespace Dune {
   template<int dim, int dimworld, typename ctype>
   inline SGrid<dim,dimworld,ctype>::SGrid (const int * const N_, const ctype * const L_, const ctype * const H_)
   {
-    dune_static_assert(dimworld <= std::numeric_limits<int>::digits, "dimworld is too large!");
+    static_assert(dimworld <= std::numeric_limits<int>::digits, "dimworld is too large!");
 
     array<int,dim> N;
     FieldVector<ctype,dim> L(0.0);
@@ -595,7 +604,7 @@ namespace Dune {
   inline SGrid<dim,dimworld,ctype>::SGrid (FieldVector<int,dim> N_, FieldVector<ctype,dim> L_,
                                            FieldVector<ctype,dim> H_)
   {
-    dune_static_assert(dimworld <= std::numeric_limits<int>::digits, "dimworld is too large!");
+    static_assert(dimworld <= std::numeric_limits<int>::digits, "dimworld is too large!");
 
     array<int,dim> N;
     for (int i=0; i<dim; i++ ) N[i] = N_[i];
@@ -606,7 +615,7 @@ namespace Dune {
   template<int dim, int dimworld, typename ctype>
   inline SGrid<dim,dimworld,ctype>::SGrid ()
   {
-    dune_static_assert(dimworld <= std::numeric_limits<int>::digits, "dimworld is too large!");
+    static_assert(dimworld <= std::numeric_limits<int>::digits, "dimworld is too large!");
 
     array<int,dim> N_;
     FieldVector<ctype,dim> L_(0.0);
