@@ -16,16 +16,16 @@
 
 #include "../common/boundaryprojection.hh"
 
-#include "gridcheck.cc"
-#include "checkgeometryinfather.cc"
-#include "checkgeometry.cc"
-#include "checkintersectionit.cc"
-#include "checkcommunicate.cc"
-#include "checkiterators.cc"
-#include "checktwists.cc"
-#include "check-albertareader.cc"
-#include "checkadaptation.cc"
-#include "checkpartition.cc"
+#include "gridcheck.hh"
+#include "checkgeometryinfather.hh"
+#include "checkgeometry.hh"
+#include "checkintersectionit.hh"
+#include "checkcommunicate.hh"
+#include "checkiterators.hh"
+#include "checktwists.hh"
+#include "check-albertareader.hh"
+#include "checkadaptation.hh"
+#include "checkpartition.hh"
 
 
 template< int dim, int dimworld >
@@ -125,19 +125,19 @@ try {
     // check grid adaptation interface
     checkAdaptation( grid );
 
-    checkPartitionType( grid.leafView() );
+    checkPartitionType( grid.leafGridView() );
 
-    checkIterators( grid.leafView() );
+    checkIterators( grid.leafGridView() );
     checkIntersectionIterator(grid,true);
-    checkTwists( grid.leafView(), NoMapTwist() );
+    checkTwists( grid.leafGridView(), NoMapTwist() );
     for(int i=0; i<1; i++)
     {
       std::cout << ">>> Refining grid and checking again..." << std::endl;
       grid.globalRefine( 1 );
       gridcheck(grid);
-      checkIterators( grid.leafView() );
+      checkIterators( grid.leafGridView() );
       checkIntersectionIterator(grid,true);
-      checkTwists( grid.leafView(), NoMapTwist() );
+      checkTwists( grid.leafGridView(), NoMapTwist() );
     }
 
     // check dgf grid width half refinement
@@ -146,21 +146,21 @@ try {
               << " times) and checking again..." << std::endl;
     grid.globalRefine( stepsForHalf );
     gridcheck(grid);
-    checkIterators( grid.leafView() );
+    checkIterators( grid.leafGridView() );
     checkIntersectionIterator(grid,true);
-    checkTwists( grid.leafView(), NoMapTwist() );
+    checkTwists( grid.leafGridView(), NoMapTwist() );
 
     for(int i=0; i<2; i++)
     {
       std::cout << ">>> Refining one element and checking again..." << std::endl;
       markOne(grid,0,dim);
       gridcheck(grid);
-      checkIterators( grid.leafView() );
+      checkIterators( grid.leafGridView() );
     }
 
     checkGeometryInFather(grid);
     checkIntersectionIterator(grid,true);
-    checkTwists( grid.leafView(), NoMapTwist() );
+    checkTwists( grid.leafGridView(), NoMapTwist() );
 
     checkCommunication(grid, -1, Dune::dvverb);
   };
