@@ -24,13 +24,13 @@
 
 #include "functions.hh"
 
-#include "gridcheck.cc"
-#include "checkcommunicate.cc"
-#include "checkgeometryinfather.cc"
-#include "checkintersectionit.cc"
-#include "checkiterators.cc"
-#include "checkpartition.cc"
-#include "checkgeometry.cc"
+#include "gridcheck.hh"
+#include "checkcommunicate.hh"
+#include "checkgeometryinfather.hh"
+#include "checkintersectionit.hh"
+#include "checkiterators.hh"
+#include "checkpartition.hh"
+#include "checkgeometry.hh"
 
 namespace Dune
 {
@@ -85,7 +85,6 @@ void test(const std::string& gridfile)
 
   std::cerr << "Checking geometry... " << std::endl;
   checkGeometry( geogrid.leafGridView() );
-
   for( int i = 0; i <= geogrid.maxLevel(); ++i )
     checkGeometry( geogrid.levelGridView( i ) );
 
