@@ -1,6 +1,5 @@
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
-// $Id$
 
 #include <config.h>
 
@@ -9,10 +8,10 @@
 
 #include <dune/grid/onedgrid.hh>
 
-#include "gridcheck.cc"
-#include "checkgeometryinfather.cc"
-#include "checkintersectionit.cc"
-#include "checkadaptation.cc"
+#include "gridcheck.hh"
+#include "checkgeometryinfather.hh"
+#include "checkintersectionit.hh"
+#include "checkadaptation.hh"
 
 using namespace Dune;
 
@@ -51,8 +50,8 @@ OneDGrid* testFactory()
   // //////////////////////////////////////////////////////////////
   //   Test whether the vertex numbering is in insertion order
   // //////////////////////////////////////////////////////////////
-  OneDGrid::Codim<1>::LevelIterator vIt    = grid->lbegin<1>(0);
-  OneDGrid::Codim<1>::LevelIterator vEndIt = grid->lend<1>(0);
+  OneDGrid::Codim<1>::LevelIterator vIt    = grid->levelGridView(0).begin<1>();
+  OneDGrid::Codim<1>::LevelIterator vEndIt = grid->levelGridView(0).end<1>();
 
   const OneDGrid::LevelGridView::IndexSet& levelIndexSet = grid->levelGridView(0).indexSet();
   const OneDGrid::LeafGridView::IndexSet&  leafIndexSet  = grid->leafGridView().indexSet();
@@ -81,8 +80,8 @@ OneDGrid* testFactory()
   elementCenters[4] = 0.1;
   elementCenters[5] = 0.25;
 
-  OneDGrid::Codim<0>::LevelIterator eIt    = grid->lbegin<0>(0);
-  OneDGrid::Codim<0>::LevelIterator eEndIt = grid->lend<0>(0);
+  OneDGrid::Codim<0>::LevelIterator eIt    = grid->levelGridView(0).begin<0>();
+  OneDGrid::Codim<0>::LevelIterator eEndIt = grid->levelGridView(0).end<0>();
 
   for (; eIt!=eEndIt; ++eIt) {
     unsigned int idx = levelIndexSet.index(*eIt);
@@ -104,7 +103,7 @@ OneDGrid* testFactory()
   typedef  GridView::IntersectionIterator IntersectionIterator;
   const GridView gridView = grid->leafGridView();
 
-  for (eIt = grid->lbegin<0>(0); eIt!=eEndIt; ++eIt) {
+  for (eIt = grid->levelGridView(0).begin<0>(); eIt!=eEndIt; ++eIt) {
     IntersectionIterator iIt = gridView.ibegin(*eIt);
     const IntersectionIterator iEndIt = gridView.iend(*eIt);
 
@@ -165,7 +164,7 @@ void testOneDGrid(OneDGrid& grid)
 int main () try
 {
   // Create a OneDGrid using the grid factory and test it
-  std::auto_ptr<Dune::OneDGrid> factoryGrid(testFactory());
+  std::unique_ptr<Dune::OneDGrid> factoryGrid(testFactory());
 
   testOneDGrid(*factoryGrid.get());
 
