@@ -4,12 +4,14 @@
 #include <config.h>
 
 #include <set>
+#include <map>
 
 #include <dune/grid/uggrid.hh>
 
 /** \todo Remove the following include once getAllSubfaces... is gone */
 #include <dune/common/sllist.hh>
 #include <dune/common/stdstreams.hh>
+#include <dune/grid/common/mcmgmapper.hh>
 
 
 using namespace Dune;
@@ -128,6 +130,9 @@ Dune::UGGrid < dim >::UGGrid()
 
 template < int dim >
 Dune::UGGrid < dim >::~UGGrid()
+#if HAVE_NOEXCEPT_SPECIFIER
+  noexcept(false)
+#endif
 {
   // Delete the UG multigrid if there is one (== createEnd() has been called)
   if (multigrid_) {
@@ -343,7 +348,7 @@ bool Dune::UGGrid < dim >::adapt()
   // I don't really know what this means
   int seq = UG_NS<dim>::GM_REFINE_PARALLEL;
 
-  // I don't really know what this means either
+  // Skip test whether we have enough memory available
   int mgtest = UG_NS<dim>::GM_REFINE_NOHEAPTEST;
 
   int rv = AdaptMultiGrid(multigrid_,mode,seq,mgtest);
@@ -401,10 +406,10 @@ void Dune::UGGrid < dim >::globalRefine(int n)
 }
 
 template <int dim>
-void Dune::UGGrid<dim>::getChildrenOfSubface(const typename Traits::template Codim<0>::EntityPointer & e,
+void Dune::UGGrid<dim>::getChildrenOfSubface(const typename Traits::template Codim<0>::Entity & e,
                                              int elementSide,
                                              int maxl,
-                                             std::vector<typename Traits::template Codim<0>::EntityPointer>& childElements,
+                                             std::vector<typename Traits::template Codim<0>::Entity>& childElements,
                                              std::vector<unsigned char>& childElementSides) const
 {
 
@@ -416,19 +421,19 @@ void Dune::UGGrid<dim>::getChildrenOfSubface(const typename Traits::template Cod
   //   Change the input face number from Dune numbering to UG numbering
   // //////////////////////////////////////////////////////////////////////
 
-  elementSide = UGGridRenumberer<dim>::facesDUNEtoUG(elementSide, e->type());
+  elementSide = UGGridRenumberer<dim>::facesDUNEtoUG(elementSide, e.type());
 
   // ///////////////
   //   init list
   // ///////////////
-  if (!e->isLeaf()   // Get_Sons_of_ElementSide returns GM_FATAL when called for a leaf !?!
-      && e->level() < maxl) {
+  if (!e.isLeaf()   // Get_Sons_of_ElementSide returns GM_FATAL when called for a leaf !?!
+      && e.level() < maxl) {
 
-    typename UG_NS<dim>::Element* theElement = this->getRealImplementation(*e).target_;
+    typename UG_NS<dim>::Element* theElement = this->getRealImplementation(e).target_;
 
-    int Sons_of_Side = 0;
+    UG::INT Sons_of_Side = 0;
     typename UG_NS<dim>::Element* SonList[UG_NS<dim>::MAX_SONS];
-    int SonSides[UG_NS<dim>::MAX_SONS];
+    UG::INT SonSides[UG_NS<dim>::MAX_SONS];
 
     int rv = Get_Sons_of_ElementSide(theElement,
                                      elementSide,
@@ -455,9 +460,9 @@ void Dune::UGGrid<dim>::getChildrenOfSubface(const typename Traits::template Cod
     typename UG_NS<dim>::Element* theElement = f->first;
     int side                                  = f->second;
 
-    int Sons_of_Side = 0;
+    UG::INT Sons_of_Side = 0;
     typename UG_NS<dim>::Element* SonList[UG_NS<dim>::MAX_SONS];
-    int SonSides[UG_NS<dim>::MAX_SONS];
+    UG::INT SonSides[UG_NS<dim>::MAX_SONS];
 
     if (UG_NS<dim>::myLevel(theElement) < maxl) {
 
@@ -490,51 +495,29 @@ void Dune::UGGrid<dim>::getChildrenOfSubface(const typename Traits::template Cod
   {
 
     // Set element
-    typedef typename Traits::template Codim< 0 >::EntityPointer EntityPointer;
-    childElements.push_back( EntityPointer( UGGridEntityPointer< 0, const UGGrid< dim > >( f->first, this ) ) );
+    typedef typename Traits::template Codim< 0 >::Entity Entity;
+    childElements.push_back( Entity( UGGridEntity< 0, dim, const UGGrid< dim > >( f->first, this ) ) );
 
     int side = f->second;
 
     // Dune numbers the faces of several elements differently than UG.
     // The following switch does the transformation
-    childElementSides[i] = UGGridRenumberer<dim>::facesUGtoDUNE(side, childElements[i]->type());
+    childElementSides[i] = UGGridRenumberer<dim>::facesUGtoDUNE(side, childElements[i].type());
 
   }
 
 }
 
 template < int dim >
-bool Dune::UGGrid < dim >::loadBalance(int strategy, int minlevel, int depth, int maxLevel, int minelement)
+bool Dune::UGGrid < dim >::loadBalance(int minlevel)
 {
   // Do nothing if we are on a single process
   if (comm().size()==1)
     return true;
 
-  /** \todo Test for valid arguments */
-  std::string argStrings[4];
-  std::stringstream numberAsAscii[4];
-
-  numberAsAscii[0] << strategy;
-  argStrings[0] = "lb " + numberAsAscii[0].str();
-
-  numberAsAscii[1] << minlevel;
-  argStrings[1] = "c " + numberAsAscii[1].str();
-
-  numberAsAscii[2] << depth;
-  argStrings[2] = "d " + numberAsAscii[2].str();
-
-  numberAsAscii[3] << minelement;
-  argStrings[3] = "e " + numberAsAscii[3].str();
-
-  const char* argv[4] = {argStrings[0].c_str(),
-                         argStrings[1].c_str(),
-                         argStrings[2].c_str(),
-                         argStrings[3].c_str()};
-
-  int errCode = UG_NS<dim>::LBCommand(4, argv);
-
-  if (errCode)
-    DUNE_THROW(GridError, "UG" << dim << "d::LBCommand returned error code " << errCode);
+  std::stringstream levelarg;
+  levelarg << minlevel;
+  UG_NS<dim>::lbs(levelarg.str().c_str(), multigrid_);
 
   // Renumber everything.
   // Note: this must not be called when on a single process, because it renumbers the zero-level
@@ -544,12 +527,94 @@ bool Dune::UGGrid < dim >::loadBalance(int strategy, int minlevel, int depth, in
   return true;
 }
 
+template < int dim >
+bool Dune::UGGrid < dim >::loadBalance(const std::vector<unsigned int>& targetProcessors, unsigned int fromLevel)
+{
+  // Do nothing if we are on a single process
+  if (comm().size()==1)
+    return true;
+
+#ifdef ModelP  // The Partition field only exists if ModelP is set
+  if (targetProcessors.size() != this->leafGridView().size(0))
+    DUNE_THROW(Exception, "targetProcessors argument does not have the correct size");
+
+  // Get unique consecutive index across different element types
+  typedef MultipleCodimMultipleGeomTypeMapper<typename Base::LeafGridView, MCMGElementLayout> ElementMapper;
+  ElementMapper elementMapper(this->leafGridView());
+
+  // Loop over all elements of all level, in decreasing level number.
+  // If the element is a leaf, take its target rank from the input targetProcessors array.
+  // If it is not, assign it to the processor most of its children are assigned to.
+  for (int i=maxLevel(); i>=0; i--) {
+
+    typename Base::LevelGridView levelGridView = this->levelGridView(i);
+    typedef typename Base::LevelGridView::template Codim<0>::template Partition<Interior_Partition>::Iterator LevelElementIterator;
+
+    for (LevelElementIterator it = levelGridView.template begin<0, Interior_Partition>();
+         it != levelGridView.template end<0, Interior_Partition>();
+         ++it) {
+
+      if (it->isLeaf()) {
+
+        unsigned int targetRank = targetProcessors[elementMapper.index(*it)];
+
+        // sanity check
+        if (targetRank >= comm().size())
+          DUNE_THROW(GridError, "Requesting target processor " << targetRank <<
+                     ", but only " << comm().size() << " processors are available.");
+
+        UG_NS<dim>::Partition(this->getRealImplementation(*it).target_) = targetRank;
+      } else {
+
+        std::map<int,int> rank;
+        unsigned int mostFrequentRank = 0;    // which rank occurred most often?
+        unsigned int mostFrequentCount = 0;   // how often did it occur?
+
+        // Loop over all children and collect the ranks they are assigned to
+        typename Base::LevelGridView::template Codim<0>::Entity::HierarchicIterator child    = it->hbegin(it->level()+1);
+        typename Base::LevelGridView::template Codim<0>::Entity::HierarchicIterator endChild = it->hend(it->level()+1);
+        for (; child !=  endChild; ++child) {
+
+          int childRank = UG_NS<dim>::Partition(this->getRealImplementation(*child).target_);
+
+          if (rank.find(childRank) == rank.end())
+            rank[childRank] = 1;
+          else
+            rank[childRank]++;
+
+          if (rank[childRank] > mostFrequentCount) {
+            mostFrequentRank = childRank;
+            mostFrequentCount = rank[childRank];
+          }
+
+        }
+
+        // Assign rank that occurred most often
+        UG_NS<dim>::Partition(this->getRealImplementation(*it).target_) = mostFrequentRank;
+
+      }
+    }
+  }
+#endif
+
+  int errCode = UG_NS<dim>::TransferGridFromLevel(multigrid_, fromLevel);
+
+  if (errCode)
+    DUNE_THROW(GridError, "UG" << dim << "d::TransferGridFromLevel returned error code " << errCode);
+
+  // Renumber everything.
+  // Note: this must not be called when on a single process, because it renumbers the zero-level
+  // elements and vertices.
+  setIndices(true, NULL);
+
+  return true;
+}
 
 template < int dim >
-void Dune::UGGrid < dim >::setPosition(const typename Traits::template Codim<dim>::EntityPointer& e,
+void Dune::UGGrid < dim >::setPosition(const typename Traits::template Codim<dim>::Entity& e,
                                        const FieldVector<double, dim>& pos)
 {
-  typename UG_NS<dim>::Node* target = this->getRealImplementation(*e).target_;
+  typename UG_NS<dim>::Node* target = this->getRealImplementation(e).target_;
 
   for (int i=0; i<dim; i++)
     target->myvertex->iv.x[i] = pos[i];
@@ -621,79 +686,6 @@ template < int dim >
 void Dune::UGGrid < dim >::setIndices(bool setLevelZero,
                                       std::vector<unsigned int>* nodePermutation)
 {
-  /** \todo The code in the following if-clause contains two workarounds to fix FlySpray issues 170
-      (inconsistent codim 1 subIndices) and 810 (Destructor of parallel UGGrid fails).
-
-      UGGrid uses UG's SideVector data structure to store the codim 1 subIndices of elements.
-      However the UG SideVector code is buggy and SideVectors are not correctly created during
-      refinement and load balancing.  In particular
-        - after refinement there may be _two_ SideVector objects for a single face,
-          instead of only one,
-        - After load balancing, and also after refinement, the VCOUNT field of the SideVector
-          (which stores how many elements reference the SideVector) is sometimes not correct.
-
-      I provide a workaround because it is outside of my capabilities to actually fix these
-      issues in UG itself.  I'd probably screw up other things if I started to mess around
-      in the UG refinement routines.
-
-      If ever UGGrid stops relying on SideVectors to store indices the following
-      if-clause can be deleted.
-   */
-  if (dim==3) {
-
-    for (int i=0; i<=maxLevel(); i++) {
-      typedef typename Base::LevelGridView GridView;
-      GridView gridView = this->levelGridView( i );
-
-      typedef typename GridView::template Codim<0>::Iterator Iterator;
-      const Iterator end = gridView.template end<0>();
-      for (Iterator it = gridView.template begin<0>(); it != end; ++it) {
-        const typename GridView::template Codim<0>::Entity &entity = *it;
-        const GeometryType gt = entity.type();
-
-        typename UG_NS<dim>::Element* elem0 = this->getRealImplementation(entity).target_;
-
-        typedef typename GridView::IntersectionIterator IntersectionIterator;
-        const IntersectionIterator iend = gridView.iend(entity);
-        for (IntersectionIterator iit = gridView.ibegin(entity); iit != iend; ++iit) {
-          const typename GridView::Intersection& intersection = *iit;
-
-          const int indexInInside = intersection.indexInInside();
-
-          int side0 = UGGridRenumberer<dim>::facesDUNEtoUG(indexInInside, gt);
-
-          if (intersection.neighbor()) {
-            const typename GridView::template Codim<0>::EntityPointer pOutside = intersection.outside();
-            const typename GridView::template Codim<0>::Entity& outside = *pOutside;
-
-            const int indexInOutside = intersection.indexInOutside();
-
-            typename UG_NS<dim>::Element* elem1 = this->getRealImplementation(outside).target_;
-
-            int side1 = UGGridRenumberer<dim>::facesDUNEtoUG(indexInOutside, outside.type());
-
-            // If there are two SideVector objects instead of only one (as there should be),
-            // delete one of them.
-            // Isn't it great that UG even provides a dedicated method for this?
-            UG::D3::DisposeDoubledSideVector((typename UG_NS<3>::Grid*)multigrid_->grids[i],
-                                             (typename UG_NS<3>::Element*)elem0,
-                                             side0,
-                                             (typename UG_NS<3>::Element*)elem1,
-                                             side1);
-          }
-
-          // Set the correct value for the VCOUNT field:
-          // the number of elements adjacent to this face.
-          // This method may not be called before DisposeDoubledSideVector
-          UG_NS<dim>::setVCount(elem0, side0, (intersection.neighbor() ? 2 : 1));
-        }
-
-      }
-
-    }
-
-  }
-
   // Create new level index sets if necessary
   for (int i=levelIndexSets_.size(); i<=maxLevel(); i++)
     levelIndexSets_.push_back(make_shared<UGGridLevelIndexSet<const UGGrid<dim> > >());
