@@ -37,29 +37,43 @@ bool test(GridType &grid)
   PersistentContainer<GridType,DataType> container0(grid,0);
   PersistentContainer<GridType,DataType> container1(grid,1);
   PersistentContainer<GridType,DataType> container2(grid,2);
+  PersistentContainer<const GridType,DataType> ccontainer0(grid,0);
+  PersistentContainer<const GridType,DataType> ccontainer1(grid,1);
+  PersistentContainer<const GridType,DataType> ccontainer2(grid,2);
 
   typedef typename GridType::LeafGridView GridView;
-  const GridView &view = grid.leafView();
+  const GridView &view = grid.leafGridView();
   typedef typename GridView::template Codim<0>::Iterator EIterator;
 
   {
     const EIterator &eend = view.template end<0>();
     for(EIterator eit = view.template begin<0>(); eit != eend; ++eit)
     {
-      container0[*eit] = eit->geometry().center();
+      ccontainer0[*eit] = container0[*eit] = eit->geometry().center();
       const Dune::ReferenceElement< typename GridType::ctype, GridType::dimension > &refElement
         = Dune::ReferenceElements< typename GridType::ctype, GridType::dimension >::general( eit->type() );
-      for (int i=0; i<eit->template count<1>(); ++i)
-        container1(*eit,i) = eit->geometry().global( refElement.position(i,1) );
-      for (int i=0; i<eit->template count<2>(); ++i)
+      for (int i=0; i<eit->subEntities(1); ++i)
+        ccontainer1(*eit,i) = container1(*eit,i) = eit->geometry().global( refElement.position(i,1) );
+      for (int i=0; i<eit->subEntities(2); ++i)
         container2(*eit,i) = eit->geometry().global( refElement.position(i,2) );
     }
   }
 
+  (void) container0.size();
+  (void) container1.size();
+  (void) container2.size();
+
+  (void) ccontainer0.size();
+  (void) ccontainer1.size();
+  (void) ccontainer2.size();
+
   grid.globalRefine(1);
   container0.resize();
   container1.resize();
   container2.resize();
+  ccontainer0.resize();
+  ccontainer1.resize();
+  ccontainer2.resize();
 
   {
     const EIterator &eend = view.template end<0>();
@@ -71,6 +85,12 @@ bool test(GridType &grid)
         ret = false;
         break;
       }
+      if (ccontainer0[*eit].used == true)
+      {
+        std::cout << "ERROR: a new element is marked as 'used' in the const container - stop testing" << std::endl;
+        ret = false;
+        break;
+      }
       typename GridType::template Codim<0>::EntityPointer up = eit->father();
       while ( !container0[*up].used )
       {
@@ -90,14 +110,14 @@ bool test(GridType &grid)
       }
       const Dune::ReferenceElement< typename GridType::ctype, GridType::dimension > &refElement
         = Dune::ReferenceElements< typename GridType::ctype, GridType::dimension >::general( eit->type() );
-      for (int i=0; i<eit->template count<1>(); ++i)
+      for (int i=0; i<eit->subEntities(1); ++i)
         if ( ( container1(*up,i).coord - up->geometry().global( refElement.position(i,1) ) ).two_norm() > 1e-8 )
         {
           std::cout << "ERROR: wrong data stored in container1 - stop testing" << std::endl;
           ret = false;
           break;
         }
-      for (int i=0; i<eit->template count<2>(); ++i)
+      for (int i=0; i<eit->subEntities(2); ++i)
         if ( ( container2(*up,i).coord - up->geometry().global( refElement.position(i,2) ) ).two_norm() > 1e-8 )
         {
           std::cout << "ERROR: wrong data stored in container1 - stop testing" << std::endl;
