@@ -1,5 +1,5 @@
-// -*- tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*-
-// vi: set et ts=8 sw=2 sts=2:
+// -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
+// vi: set et ts=4 sw=2 sts=2:
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -11,6 +11,6 @@
 
 const std::string programName = "dune-structured-to-alusimplex-3d";
 static const bool useCube = false;
-typedef Dune::ALUSimplexGrid<3, 3> Grid;
+typedef Dune::ALUGrid<3, 3, Dune::simplex, Dune::nonconforming> Grid;
 
 #include "main.hh"
